/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 1.3.40
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */


using System;
using System.Runtime.InteropServices;

class zxidPINVOKE {

  protected class SWIGExceptionHelper {

    public delegate void ExceptionDelegate(string message);
    public delegate void ExceptionArgumentDelegate(string message, string paramName);

    static ExceptionDelegate applicationDelegate = new ExceptionDelegate(SetPendingApplicationException);
    static ExceptionDelegate arithmeticDelegate = new ExceptionDelegate(SetPendingArithmeticException);
    static ExceptionDelegate divideByZeroDelegate = new ExceptionDelegate(SetPendingDivideByZeroException);
    static ExceptionDelegate indexOutOfRangeDelegate = new ExceptionDelegate(SetPendingIndexOutOfRangeException);
    static ExceptionDelegate invalidCastDelegate = new ExceptionDelegate(SetPendingInvalidCastException);
    static ExceptionDelegate invalidOperationDelegate = new ExceptionDelegate(SetPendingInvalidOperationException);
    static ExceptionDelegate ioDelegate = new ExceptionDelegate(SetPendingIOException);
    static ExceptionDelegate nullReferenceDelegate = new ExceptionDelegate(SetPendingNullReferenceException);
    static ExceptionDelegate outOfMemoryDelegate = new ExceptionDelegate(SetPendingOutOfMemoryException);
    static ExceptionDelegate overflowDelegate = new ExceptionDelegate(SetPendingOverflowException);
    static ExceptionDelegate systemDelegate = new ExceptionDelegate(SetPendingSystemException);

    static ExceptionArgumentDelegate argumentDelegate = new ExceptionArgumentDelegate(SetPendingArgumentException);
    static ExceptionArgumentDelegate argumentNullDelegate = new ExceptionArgumentDelegate(SetPendingArgumentNullException);
    static ExceptionArgumentDelegate argumentOutOfRangeDelegate = new ExceptionArgumentDelegate(SetPendingArgumentOutOfRangeException);

    [DllImport("zxid", EntryPoint="SWIGRegisterExceptionCallbacks_zxid")]
    public static extern void SWIGRegisterExceptionCallbacks_zxid(
                                ExceptionDelegate applicationDelegate,
                                ExceptionDelegate arithmeticDelegate,
                                ExceptionDelegate divideByZeroDelegate, 
                                ExceptionDelegate indexOutOfRangeDelegate, 
                                ExceptionDelegate invalidCastDelegate,
                                ExceptionDelegate invalidOperationDelegate,
                                ExceptionDelegate ioDelegate,
                                ExceptionDelegate nullReferenceDelegate,
                                ExceptionDelegate outOfMemoryDelegate, 
                                ExceptionDelegate overflowDelegate, 
                                ExceptionDelegate systemExceptionDelegate);

    [DllImport("zxid", EntryPoint="SWIGRegisterExceptionArgumentCallbacks_zxid")]
    public static extern void SWIGRegisterExceptionCallbacksArgument_zxid(
                                ExceptionArgumentDelegate argumentDelegate,
                                ExceptionArgumentDelegate argumentNullDelegate,
                                ExceptionArgumentDelegate argumentOutOfRangeDelegate);

    static void SetPendingApplicationException(string message) {
      SWIGPendingException.Set(new System.ApplicationException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingArithmeticException(string message) {
      SWIGPendingException.Set(new System.ArithmeticException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingDivideByZeroException(string message) {
      SWIGPendingException.Set(new System.DivideByZeroException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingIndexOutOfRangeException(string message) {
      SWIGPendingException.Set(new System.IndexOutOfRangeException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingInvalidCastException(string message) {
      SWIGPendingException.Set(new System.InvalidCastException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingInvalidOperationException(string message) {
      SWIGPendingException.Set(new System.InvalidOperationException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingIOException(string message) {
      SWIGPendingException.Set(new System.IO.IOException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingNullReferenceException(string message) {
      SWIGPendingException.Set(new System.NullReferenceException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingOutOfMemoryException(string message) {
      SWIGPendingException.Set(new System.OutOfMemoryException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingOverflowException(string message) {
      SWIGPendingException.Set(new System.OverflowException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingSystemException(string message) {
      SWIGPendingException.Set(new System.SystemException(message, SWIGPendingException.Retrieve()));
    }

    static void SetPendingArgumentException(string message, string paramName) {
      SWIGPendingException.Set(new System.ArgumentException(message, paramName, SWIGPendingException.Retrieve()));
    }
    static void SetPendingArgumentNullException(string message, string paramName) {
      Exception e = SWIGPendingException.Retrieve();
      if (e != null) message = message + " Inner Exception: " + e.Message;
      SWIGPendingException.Set(new System.ArgumentNullException(paramName, message));
    }
    static void SetPendingArgumentOutOfRangeException(string message, string paramName) {
      Exception e = SWIGPendingException.Retrieve();
      if (e != null) message = message + " Inner Exception: " + e.Message;
      SWIGPendingException.Set(new System.ArgumentOutOfRangeException(paramName, message));
    }

    static SWIGExceptionHelper() {
      SWIGRegisterExceptionCallbacks_zxid(
                                applicationDelegate,
                                arithmeticDelegate,
                                divideByZeroDelegate,
                                indexOutOfRangeDelegate,
                                invalidCastDelegate,
                                invalidOperationDelegate,
                                ioDelegate,
                                nullReferenceDelegate,
                                outOfMemoryDelegate,
                                overflowDelegate,
                                systemDelegate);

      SWIGRegisterExceptionCallbacksArgument_zxid(
                                argumentDelegate,
                                argumentNullDelegate,
                                argumentOutOfRangeDelegate);
    }
  }

  protected static SWIGExceptionHelper swigExceptionHelper = new SWIGExceptionHelper();

  public class SWIGPendingException {
    [ThreadStatic]
    private static Exception pendingException = null;
    private static int numExceptionsPending = 0;

    public static bool Pending {
      get {
        bool pending = false;
        if (numExceptionsPending > 0)
          if (pendingException != null)
            pending = true;
        return pending;
      } 
    }

    public static void Set(Exception e) {
      if (pendingException != null)
        throw new ApplicationException("FATAL: An earlier pending exception from unmanaged code was missed and thus not thrown (" + pendingException.ToString() + ")", e);
      pendingException = e;
      lock(typeof(zxidPINVOKE)) {
        numExceptionsPending++;
      }
    }

    public static Exception Retrieve() {
      Exception e = null;
      if (numExceptionsPending > 0) {
        if (pendingException != null) {
          e = pendingException;
          pendingException = null;
          lock(typeof(zxidPINVOKE)) {
            numExceptionsPending--;
          }
        }
      }
      return e;
    }
  }


  protected class SWIGStringHelper {

    public delegate string SWIGStringDelegate(string message);
    static SWIGStringDelegate stringDelegate = new SWIGStringDelegate(CreateString);

    [DllImport("zxid", EntryPoint="SWIGRegisterStringCallback_zxid")]
    public static extern void SWIGRegisterStringCallback_zxid(SWIGStringDelegate stringDelegate);

    static string CreateString(string cString) {
      return cString;
    }

    static SWIGStringHelper() {
      SWIGRegisterStringCallback_zxid(stringDelegate);
    }
  }

  static protected SWIGStringHelper swigStringHelper = new SWIGStringHelper();


  [DllImport("zxid", EntryPoint="CSharp_ZXERR_EOF_get")]
  public static extern int ZXERR_EOF_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXERR_MISMATCH_CLOSE_get")]
  public static extern int ZXERR_MISMATCH_CLOSE_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXERR_BAD_ATTR_NS_get")]
  public static extern int ZXERR_BAD_ATTR_NS_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXERR_BAD_ELEM_NS_get")]
  public static extern int ZXERR_BAD_ELEM_NS_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXERR_MISSING_ATTR_get")]
  public static extern int ZXERR_MISSING_ATTR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXERR_EXTRA_ATTR_get")]
  public static extern int ZXERR_EXTRA_ATTR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXERR_MISSING_ELEM_get")]
  public static extern int ZXERR_MISSING_ELEM_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXERR_EXTRA_ELEM_get")]
  public static extern int ZXERR_EXTRA_ELEM_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXERR_ELEM_ORDER_get")]
  public static extern int ZXERR_ELEM_ORDER_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXERR_BAD_NS_PREFIX_get")]
  public static extern int ZXERR_BAD_NS_PREFIX_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXERR_TAG_NOT_CLOSED_get")]
  public static extern int ZXERR_TAG_NOT_CLOSED_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXERR_MASK_get")]
  public static extern int ZXERR_MASK_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXERR_ATTR_FLAG_get")]
  public static extern int ZXERR_ATTR_FLAG_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_n_set")]
  public static extern void zx_ns_s_n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_n_get")]
  public static extern IntPtr zx_ns_s_n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_m_set")]
  public static extern void zx_ns_s_m_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_m_get")]
  public static extern IntPtr zx_ns_s_m_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_seen_set")]
  public static extern void zx_ns_s_seen_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_seen_get")]
  public static extern IntPtr zx_ns_s_seen_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_seen_n_set")]
  public static extern void zx_ns_s_seen_n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_seen_n_get")]
  public static extern IntPtr zx_ns_s_seen_n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_seen_p_set")]
  public static extern void zx_ns_s_seen_p_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_seen_p_get")]
  public static extern IntPtr zx_ns_s_seen_p_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_seen_pop_set")]
  public static extern void zx_ns_s_seen_pop_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_seen_pop_get")]
  public static extern IntPtr zx_ns_s_seen_pop_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_inc_n_set")]
  public static extern void zx_ns_s_inc_n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_inc_n_get")]
  public static extern IntPtr zx_ns_s_inc_n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_prefix_len_set")]
  public static extern void zx_ns_s_prefix_len_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_prefix_len_get")]
  public static extern int zx_ns_s_prefix_len_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_prefix_set")]
  public static extern void zx_ns_s_prefix_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_prefix_get")]
  public static extern string zx_ns_s_prefix_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_url_len_set")]
  public static extern void zx_ns_s_url_len_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_url_len_get")]
  public static extern int zx_ns_s_url_len_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_url_set")]
  public static extern void zx_ns_s_url_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_s_url_get")]
  public static extern string zx_ns_s_url_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zx_ns_s")]
  public static extern IntPtr new_zx_ns_s();

  [DllImport("zxid", EntryPoint="CSharp_delete_zx_ns_s")]
  public static extern void delete_zx_ns_s(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx__base_set")]
  public static extern void zx_ctx__base_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx__base_get")]
  public static extern string zx_ctx__base_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_p_set")]
  public static extern void zx_ctx_p_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_p_get")]
  public static extern string zx_ctx_p_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_lim_set")]
  public static extern void zx_ctx_lim_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_lim_get")]
  public static extern string zx_ctx_lim_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_ns_tab_set")]
  public static extern void zx_ctx_ns_tab_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_ns_tab_get")]
  public static extern IntPtr zx_ctx_ns_tab_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_unknown_ns_set")]
  public static extern void zx_ctx_unknown_ns_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_unknown_ns_get")]
  public static extern IntPtr zx_ctx_unknown_ns_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_guard_seen_n_set")]
  public static extern void zx_ctx_guard_seen_n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_guard_seen_n_get")]
  public static extern IntPtr zx_ctx_guard_seen_n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_guard_seen_p_set")]
  public static extern void zx_ctx_guard_seen_p_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_guard_seen_p_get")]
  public static extern IntPtr zx_ctx_guard_seen_p_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_exclude_sig_set")]
  public static extern void zx_ctx_exclude_sig_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_exclude_sig_get")]
  public static extern IntPtr zx_ctx_exclude_sig_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_inc_ns_len_set")]
  public static extern void zx_ctx_inc_ns_len_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_inc_ns_len_get")]
  public static extern IntPtr zx_ctx_inc_ns_len_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_inc_ns_set")]
  public static extern void zx_ctx_inc_ns_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_inc_ns_get")]
  public static extern IntPtr zx_ctx_inc_ns_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_malloc_func_set")]
  public static extern void zx_ctx_malloc_func_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_malloc_func_get")]
  public static extern IntPtr zx_ctx_malloc_func_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_realloc_func_set")]
  public static extern void zx_ctx_realloc_func_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_realloc_func_get")]
  public static extern IntPtr zx_ctx_realloc_func_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_free_func_set")]
  public static extern void zx_ctx_free_func_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ctx_free_func_get")]
  public static extern IntPtr zx_ctx_free_func_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zx_ctx")]
  public static extern IntPtr new_zx_ctx();

  [DllImport("zxid", EntryPoint="CSharp_delete_zx_ctx")]
  public static extern void delete_zx_ctx(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_node_s_n_set")]
  public static extern void zx_node_s_n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_node_s_n_get")]
  public static extern IntPtr zx_node_s_n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_node_s_wo_set")]
  public static extern void zx_node_s_wo_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_node_s_wo_get")]
  public static extern IntPtr zx_node_s_wo_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_node_s_ns_set")]
  public static extern void zx_node_s_ns_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_node_s_ns_get")]
  public static extern IntPtr zx_node_s_ns_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_node_s_tok_set")]
  public static extern void zx_node_s_tok_set(HandleRef jarg1, short jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_node_s_tok_get")]
  public static extern short zx_node_s_tok_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_node_s_err_set")]
  public static extern void zx_node_s_err_set(HandleRef jarg1, short jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_node_s_err_get")]
  public static extern short zx_node_s_err_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zx_node_s")]
  public static extern IntPtr new_zx_node_s();

  [DllImport("zxid", EntryPoint="CSharp_delete_zx_node_s")]
  public static extern void delete_zx_node_s(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_elem_s_g_set")]
  public static extern void zx_elem_s_g_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_elem_s_g_get")]
  public static extern IntPtr zx_elem_s_g_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_elem_s_kids_set")]
  public static extern void zx_elem_s_kids_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_elem_s_kids_get")]
  public static extern IntPtr zx_elem_s_kids_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_elem_s_any_attr_set")]
  public static extern void zx_elem_s_any_attr_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_elem_s_any_attr_get")]
  public static extern IntPtr zx_elem_s_any_attr_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_elem_s_any_elem_set")]
  public static extern void zx_elem_s_any_elem_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_elem_s_any_elem_get")]
  public static extern IntPtr zx_elem_s_any_elem_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_elem_s_xmlns_set")]
  public static extern void zx_elem_s_xmlns_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_elem_s_xmlns_get")]
  public static extern IntPtr zx_elem_s_xmlns_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_elem_s_content_set")]
  public static extern void zx_elem_s_content_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_elem_s_content_get")]
  public static extern IntPtr zx_elem_s_content_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zx_elem_s")]
  public static extern IntPtr new_zx_elem_s();

  [DllImport("zxid", EntryPoint="CSharp_delete_zx_elem_s")]
  public static extern void delete_zx_elem_s(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_new_simple_elem")]
  public static extern IntPtr zx_new_simple_elem(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ref_len_simple_elem")]
  public static extern IntPtr zx_ref_len_simple_elem(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ref_simple_elem")]
  public static extern IntPtr zx_ref_simple_elem(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_dup_len_simple_elem")]
  public static extern IntPtr zx_dup_len_simple_elem(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_dup_simple_elem")]
  public static extern IntPtr zx_dup_simple_elem(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_str_g_set")]
  public static extern void zx_str_g_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_str_g_get")]
  public static extern IntPtr zx_str_g_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_str_len_set")]
  public static extern void zx_str_len_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_str_len_get")]
  public static extern int zx_str_len_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_str_s_set")]
  public static extern void zx_str_s_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_str_s_get")]
  public static extern string zx_str_s_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zx_str")]
  public static extern IntPtr new_zx_str();

  [DllImport("zxid", EntryPoint="CSharp_delete_zx_str")]
  public static extern void delete_zx_str(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ref_str")]
  public static extern IntPtr zx_ref_str(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_ref_len_str")]
  public static extern IntPtr zx_ref_len_str(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_new_len_str")]
  public static extern IntPtr zx_new_len_str(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_dup_str")]
  public static extern IntPtr zx_dup_str(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_dup_len_str")]
  public static extern IntPtr zx_dup_len_str(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_alloc_sprintf")]
  public static extern string zx_alloc_sprintf(HandleRef jarg1, HandleRef jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_strf")]
  public static extern IntPtr zx_strf(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_str_free")]
  public static extern void zx_str_free(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_str_to_c")]
  public static extern string zx_str_to_c(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_str_conv")]
  public static extern void zx_str_conv(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_str_ends_in")]
  public static extern int zx_str_ends_in(HandleRef jarg1, int jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_any_elem_s_gg_set")]
  public static extern void zx_any_elem_s_gg_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_any_elem_s_gg_get")]
  public static extern IntPtr zx_any_elem_s_gg_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_any_elem_s_name_len_set")]
  public static extern void zx_any_elem_s_name_len_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_any_elem_s_name_len_get")]
  public static extern int zx_any_elem_s_name_len_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_any_elem_s_name_set")]
  public static extern void zx_any_elem_s_name_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_any_elem_s_name_get")]
  public static extern string zx_any_elem_s_name_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zx_any_elem_s")]
  public static extern IntPtr new_zx_any_elem_s();

  [DllImport("zxid", EntryPoint="CSharp_delete_zx_any_elem_s")]
  public static extern void delete_zx_any_elem_s(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_any_attr_s_ss_set")]
  public static extern void zx_any_attr_s_ss_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_any_attr_s_ss_get")]
  public static extern IntPtr zx_any_attr_s_ss_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_any_attr_s_name_len_set")]
  public static extern void zx_any_attr_s_name_len_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_any_attr_s_name_len_get")]
  public static extern int zx_any_attr_s_name_len_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_any_attr_s_name_set")]
  public static extern void zx_any_attr_s_name_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_any_attr_s_name_get")]
  public static extern string zx_any_attr_s_name_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zx_any_attr_s")]
  public static extern IntPtr new_zx_any_attr_s();

  [DllImport("zxid", EntryPoint="CSharp_delete_zx_any_attr_s")]
  public static extern void delete_zx_any_attr_s(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_memmem")]
  public static extern string zx_memmem(string jarg1, int jarg2, string jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_alloc")]
  public static extern IntPtr zx_alloc(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_zalloc")]
  public static extern IntPtr zx_zalloc(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_free")]
  public static extern IntPtr zx_free(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_dup_cstr")]
  public static extern string zx_dup_cstr(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_reset_ctx")]
  public static extern void zx_reset_ctx(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_init_ctx")]
  public static extern IntPtr zx_init_ctx();

  [DllImport("zxid", EntryPoint="CSharp_ZX_TOK_XMLNS_get")]
  public static extern int ZX_TOK_XMLNS_get();

  [DllImport("zxid", EntryPoint="CSharp_ZX_TOK_DATA_get")]
  public static extern int ZX_TOK_DATA_get();

  [DllImport("zxid", EntryPoint="CSharp_ZX_TOK_NOT_FOUND_get")]
  public static extern int ZX_TOK_NOT_FOUND_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_tok_name_set")]
  public static extern void zx_tok_name_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_tok_name_get")]
  public static extern string zx_tok_name_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_tok_prefix_set")]
  public static extern void zx_tok_prefix_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_tok_prefix_get")]
  public static extern string zx_tok_prefix_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_tok_ns_set")]
  public static extern void zx_tok_ns_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_tok_ns_get")]
  public static extern IntPtr zx_tok_ns_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zx_tok")]
  public static extern IntPtr new_zx_tok();

  [DllImport("zxid", EntryPoint="CSharp_delete_zx_tok")]
  public static extern void delete_zx_tok(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_date_time_to_secs")]
  public static extern int zx_date_time_to_secs(string jarg1);

  [DllImport("zxid", EntryPoint="CSharp_write2_or_append_lock_c_path")]
  public static extern int write2_or_append_lock_c_path(string jarg1, int jarg2, string jarg3, int jarg4, string jarg5, string jarg6, int jarg7, int jarg8);

  [DllImport("zxid", EntryPoint="CSharp_zx_report_openssl_error")]
  public static extern int zx_report_openssl_error(string jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_fix_any_elem_dec")]
  public static extern void zx_fix_any_elem_dec(HandleRef jarg1, HandleRef jarg2, string jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_locate_ns_by_prefix")]
  public static extern IntPtr zx_locate_ns_by_prefix(HandleRef jarg1, int jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_is_ns_prefix")]
  public static extern int zx_is_ns_prefix(HandleRef jarg1, int jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_prefix_seen")]
  public static extern IntPtr zx_prefix_seen(HandleRef jarg1, int jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_prefix_seen_whine")]
  public static extern IntPtr zx_prefix_seen_whine(HandleRef jarg1, int jarg2, string jarg3, string jarg4, int jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zx_scan_xmlns")]
  public static extern IntPtr zx_scan_xmlns(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_pop_seen")]
  public static extern void zx_pop_seen(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_raw_cipher")]
  public static extern IntPtr zx_raw_cipher(HandleRef jarg1, string jarg2, int jarg3, HandleRef jarg4, int jarg5, int jarg7, string jarg8);

  [DllImport("zxid", EntryPoint="CSharp_zx_rsa_pub_enc")]
  public static extern IntPtr zx_rsa_pub_enc(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_rsa_pub_dec")]
  public static extern IntPtr zx_rsa_pub_dec(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_rsa_priv_dec")]
  public static extern IntPtr zx_rsa_priv_dec(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_rsa_priv_enc")]
  public static extern IntPtr zx_rsa_priv_enc(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_get_rsa_pub_from_cert")]
  public static extern IntPtr zx_get_rsa_pub_from_cert(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_rand")]
  public static extern void zx_rand(string jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_md5_crypt")]
  public static extern string zx_md5_crypt(string jarg1, string jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_tok_by_ns")]
  public static extern IntPtr zx_tok_by_ns(HandleRef jarg1, HandleRef jarg2, int jarg3, string jarg4, HandleRef jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zx_len_xmlns_if_not_seen")]
  public static extern int zx_len_xmlns_if_not_seen(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_enc_xmlns_if_not_seen")]
  public static extern string zx_enc_xmlns_if_not_seen(HandleRef jarg1, string jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_add_xmlns_if_not_seen")]
  public static extern void zx_add_xmlns_if_not_seen(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_enc_seen")]
  public static extern string zx_enc_seen(string jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_len_so_common")]
  public static extern int zx_len_so_common(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_len_wo_common")]
  public static extern int zx_len_wo_common(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_enc_unknown_attrs")]
  public static extern string zx_enc_unknown_attrs(string jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_enc_so_unknown_elems_and_content")]
  public static extern string zx_enc_so_unknown_elems_and_content(HandleRef jarg1, string jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_easy_enc_common")]
  public static extern IntPtr zx_easy_enc_common(HandleRef jarg1, string jarg2, string jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_attr_so_len")]
  public static extern int zx_attr_so_len(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_attr_so_enc")]
  public static extern string zx_attr_so_enc(string jarg1, HandleRef jarg2, string jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_attr_wo_len")]
  public static extern int zx_attr_wo_len(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_attr_wo_enc")]
  public static extern string zx_attr_wo_enc(string jarg1, HandleRef jarg2, string jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_free_attr")]
  public static extern void zx_free_attr(HandleRef jarg1, HandleRef jarg2, int jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_free_elem_common")]
  public static extern void zx_free_elem_common(HandleRef jarg1, HandleRef jarg2, int jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_free_simple_elems")]
  public static extern void zx_free_simple_elems(HandleRef jarg1, HandleRef jarg2, int jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_prepare_dec_ctx")]
  public static extern void zx_prepare_dec_ctx(HandleRef jarg1, HandleRef jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_scan_data")]
  public static extern int zx_scan_data(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_scan_pi_or_comment")]
  public static extern int zx_scan_pi_or_comment(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_dec_unknown_attr")]
  public static extern IntPtr zx_dec_unknown_attr(HandleRef jarg1, HandleRef jarg2, string jarg3, string jarg4, int jarg5, int jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zx_dec_attr_val")]
  public static extern string zx_dec_attr_val(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_xml_parse_err")]
  public static extern void zx_xml_parse_err(HandleRef jarg1, char jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_len_inc_ns")]
  public static extern int zx_len_inc_ns(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_add_inc_ns")]
  public static extern void zx_add_inc_ns(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_enc_inc_ns")]
  public static extern string zx_enc_inc_ns(HandleRef jarg1, string jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_SIG_ALGO_RSA_SHA1_get")]
  public static extern string SIG_ALGO_RSA_SHA1_get();

  [DllImport("zxid", EntryPoint="CSharp_SIG_ALGO_DSA_SHA1_get")]
  public static extern string SIG_ALGO_DSA_SHA1_get();

  [DllImport("zxid", EntryPoint="CSharp_SIG_ALGO_get")]
  public static extern string SIG_ALGO_get();

  [DllImport("zxid", EntryPoint="CSharp_DIGEST_ALGO_get")]
  public static extern string DIGEST_ALGO_get();

  [DllImport("zxid", EntryPoint="CSharp_CANON_ALGO_get")]
  public static extern string CANON_ALGO_get();

  [DllImport("zxid", EntryPoint="CSharp_ENVELOPED_ALGO_get")]
  public static extern string ENVELOPED_ALGO_get();

  [DllImport("zxid", EntryPoint="CSharp_ENC_ALGO_TRIPLEDES_CBC_get")]
  public static extern string ENC_ALGO_TRIPLEDES_CBC_get();

  [DllImport("zxid", EntryPoint="CSharp_ENC_ALGO_AES128_CBC_get")]
  public static extern string ENC_ALGO_AES128_CBC_get();

  [DllImport("zxid", EntryPoint="CSharp_ENC_ALGO_AES192_CBC_get")]
  public static extern string ENC_ALGO_AES192_CBC_get();

  [DllImport("zxid", EntryPoint="CSharp_ENC_ALGO_AES256_CBC_get")]
  public static extern string ENC_ALGO_AES256_CBC_get();

  [DllImport("zxid", EntryPoint="CSharp_ENC_ALGO_get")]
  public static extern string ENC_ALGO_get();

  [DllImport("zxid", EntryPoint="CSharp_ENC_KEYTRAN_RSA_1_5_get")]
  public static extern string ENC_KEYTRAN_RSA_1_5_get();

  [DllImport("zxid", EntryPoint="CSharp_ENC_KEYTRAN_RSA_OAEP_get")]
  public static extern string ENC_KEYTRAN_RSA_OAEP_get();

  [DllImport("zxid", EntryPoint="CSharp_ENC_KEYTRAN_ALGO_get")]
  public static extern string ENC_KEYTRAN_ALGO_get();

  [DllImport("zxid", EntryPoint="CSharp_ENC_ENCKEY_METH_get")]
  public static extern string ENC_ENCKEY_METH_get();

  [DllImport("zxid", EntryPoint="CSharp_ENC_TYPE_ELEMENT_get")]
  public static extern string ENC_TYPE_ELEMENT_get();

  [DllImport("zxid", EntryPoint="CSharp_ENC_TYPE_CONTENT_get")]
  public static extern string ENC_TYPE_CONTENT_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_CONF_MAGIC_get")]
  public static extern int ZXID_CONF_MAGIC_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_CGI_MAGIC_get")]
  public static extern int ZXID_CGI_MAGIC_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SES_MAGIC_get")]
  public static extern int ZXID_SES_MAGIC_get();

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_magic_set")]
  public static extern void zxid_conf_magic_set(HandleRef jarg1, uint jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_magic_get")]
  public static extern uint zxid_conf_magic_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_ctx_set")]
  public static extern void zxid_conf_ctx_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_ctx_get")]
  public static extern IntPtr zxid_conf_ctx_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_cot_set")]
  public static extern void zxid_conf_cot_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_cot_get")]
  public static extern IntPtr zxid_conf_cot_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_path_supplied_set")]
  public static extern void zxid_conf_path_supplied_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_path_supplied_get")]
  public static extern int zxid_conf_path_supplied_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_path_len_set")]
  public static extern void zxid_conf_path_len_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_path_len_get")]
  public static extern int zxid_conf_path_len_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_path_set")]
  public static extern void zxid_conf_path_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_path_get")]
  public static extern string zxid_conf_path_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_url_set")]
  public static extern void zxid_conf_url_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_url_get")]
  public static extern string zxid_conf_url_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_non_standard_entityid_set")]
  public static extern void zxid_conf_non_standard_entityid_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_non_standard_entityid_get")]
  public static extern string zxid_conf_non_standard_entityid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_redirect_hack_imposed_url_set")]
  public static extern void zxid_conf_redirect_hack_imposed_url_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_redirect_hack_imposed_url_get")]
  public static extern string zxid_conf_redirect_hack_imposed_url_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_redirect_hack_zxid_url_set")]
  public static extern void zxid_conf_redirect_hack_zxid_url_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_redirect_hack_zxid_url_get")]
  public static extern string zxid_conf_redirect_hack_zxid_url_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_redirect_hack_zxid_qs_set")]
  public static extern void zxid_conf_redirect_hack_zxid_qs_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_redirect_hack_zxid_qs_get")]
  public static extern string zxid_conf_redirect_hack_zxid_qs_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_cdc_url_set")]
  public static extern void zxid_conf_cdc_url_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_cdc_url_get")]
  public static extern string zxid_conf_cdc_url_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_cdc_choice_set")]
  public static extern void zxid_conf_cdc_choice_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_cdc_choice_get")]
  public static extern char zxid_conf_cdc_choice_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_md_fetch_set")]
  public static extern void zxid_conf_md_fetch_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_md_fetch_get")]
  public static extern char zxid_conf_md_fetch_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_md_populate_cache_set")]
  public static extern void zxid_conf_md_populate_cache_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_md_populate_cache_get")]
  public static extern char zxid_conf_md_populate_cache_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_md_cache_first_set")]
  public static extern void zxid_conf_md_cache_first_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_md_cache_first_get")]
  public static extern char zxid_conf_md_cache_first_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_md_cache_last_set")]
  public static extern void zxid_conf_md_cache_last_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_md_cache_last_get")]
  public static extern char zxid_conf_md_cache_last_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_auto_cert_set")]
  public static extern void zxid_conf_auto_cert_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_auto_cert_get")]
  public static extern char zxid_conf_auto_cert_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_user_local_set")]
  public static extern void zxid_conf_user_local_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_user_local_get")]
  public static extern char zxid_conf_user_local_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_ena_set")]
  public static extern void zxid_conf_idp_ena_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_ena_get")]
  public static extern char zxid_conf_idp_ena_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_pdp_ena_set")]
  public static extern void zxid_conf_pdp_ena_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_pdp_ena_get")]
  public static extern char zxid_conf_pdp_ena_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_authn_req_sign_set")]
  public static extern void zxid_conf_authn_req_sign_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_authn_req_sign_get")]
  public static extern char zxid_conf_authn_req_sign_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_want_authn_req_signed_set")]
  public static extern void zxid_conf_want_authn_req_signed_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_want_authn_req_signed_get")]
  public static extern char zxid_conf_want_authn_req_signed_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_want_sso_a7n_signed_set")]
  public static extern void zxid_conf_want_sso_a7n_signed_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_want_sso_a7n_signed_get")]
  public static extern char zxid_conf_want_sso_a7n_signed_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_sso_soap_sign_set")]
  public static extern void zxid_conf_sso_soap_sign_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_sso_soap_sign_get")]
  public static extern char zxid_conf_sso_soap_sign_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_sso_soap_resp_sign_set")]
  public static extern void zxid_conf_sso_soap_resp_sign_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_sso_soap_resp_sign_get")]
  public static extern char zxid_conf_sso_soap_resp_sign_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_sso_sign_set")]
  public static extern void zxid_conf_sso_sign_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_sso_sign_get")]
  public static extern char zxid_conf_sso_sign_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_nameid_enc_set")]
  public static extern void zxid_conf_nameid_enc_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_nameid_enc_get")]
  public static extern char zxid_conf_nameid_enc_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_post_a7n_enc_set")]
  public static extern void zxid_conf_post_a7n_enc_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_post_a7n_enc_get")]
  public static extern char zxid_conf_post_a7n_enc_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_di_allow_create_set")]
  public static extern void zxid_conf_di_allow_create_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_di_allow_create_get")]
  public static extern char zxid_conf_di_allow_create_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_di_nid_fmt_set")]
  public static extern void zxid_conf_di_nid_fmt_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_di_nid_fmt_get")]
  public static extern char zxid_conf_di_nid_fmt_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_di_a7n_enc_set")]
  public static extern void zxid_conf_di_a7n_enc_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_di_a7n_enc_get")]
  public static extern char zxid_conf_di_a7n_enc_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_show_conf_set")]
  public static extern void zxid_conf_show_conf_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_show_conf_get")]
  public static extern char zxid_conf_show_conf_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_affiliation_set")]
  public static extern void zxid_conf_affiliation_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_affiliation_get")]
  public static extern string zxid_conf_affiliation_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_nice_name_set")]
  public static extern void zxid_conf_nice_name_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_nice_name_get")]
  public static extern string zxid_conf_nice_name_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_ses_arch_dir_set")]
  public static extern void zxid_conf_ses_arch_dir_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_ses_arch_dir_get")]
  public static extern string zxid_conf_ses_arch_dir_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_ses_cookie_name_set")]
  public static extern void zxid_conf_ses_cookie_name_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_ses_cookie_name_get")]
  public static extern string zxid_conf_ses_cookie_name_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_ipport_set")]
  public static extern void zxid_conf_ipport_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_ipport_get")]
  public static extern string zxid_conf_ipport_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_err_set")]
  public static extern void zxid_conf_log_err_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_err_get")]
  public static extern char zxid_conf_log_err_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_act_set")]
  public static extern void zxid_conf_log_act_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_act_get")]
  public static extern char zxid_conf_log_act_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_issue_a7n_set")]
  public static extern void zxid_conf_log_issue_a7n_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_issue_a7n_get")]
  public static extern char zxid_conf_log_issue_a7n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_issue_msg_set")]
  public static extern void zxid_conf_log_issue_msg_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_issue_msg_get")]
  public static extern char zxid_conf_log_issue_msg_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_rely_a7n_set")]
  public static extern void zxid_conf_log_rely_a7n_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_rely_a7n_get")]
  public static extern char zxid_conf_log_rely_a7n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_rely_msg_set")]
  public static extern void zxid_conf_log_rely_msg_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_rely_msg_get")]
  public static extern char zxid_conf_log_rely_msg_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_err_in_act_set")]
  public static extern void zxid_conf_log_err_in_act_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_err_in_act_get")]
  public static extern char zxid_conf_log_err_in_act_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_act_in_err_set")]
  public static extern void zxid_conf_log_act_in_err_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_act_in_err_get")]
  public static extern char zxid_conf_log_act_in_err_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_sigfail_is_err_set")]
  public static extern void zxid_conf_log_sigfail_is_err_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_sigfail_is_err_get")]
  public static extern char zxid_conf_log_sigfail_is_err_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_level_set")]
  public static extern void zxid_conf_log_level_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_log_level_get")]
  public static extern char zxid_conf_log_level_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_sig_fatal_set")]
  public static extern void zxid_conf_sig_fatal_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_sig_fatal_get")]
  public static extern char zxid_conf_sig_fatal_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_nosig_fatal_set")]
  public static extern void zxid_conf_nosig_fatal_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_nosig_fatal_get")]
  public static extern char zxid_conf_nosig_fatal_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_msg_sig_ok_set")]
  public static extern void zxid_conf_msg_sig_ok_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_msg_sig_ok_get")]
  public static extern char zxid_conf_msg_sig_ok_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_timeout_fatal_set")]
  public static extern void zxid_conf_timeout_fatal_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_timeout_fatal_get")]
  public static extern char zxid_conf_timeout_fatal_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_audience_fatal_set")]
  public static extern void zxid_conf_audience_fatal_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_audience_fatal_get")]
  public static extern char zxid_conf_audience_fatal_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_dup_a7n_fatal_set")]
  public static extern void zxid_conf_dup_a7n_fatal_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_dup_a7n_fatal_get")]
  public static extern char zxid_conf_dup_a7n_fatal_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_dup_msg_fatal_set")]
  public static extern void zxid_conf_dup_msg_fatal_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_dup_msg_fatal_get")]
  public static extern char zxid_conf_dup_msg_fatal_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_redir_to_content_set")]
  public static extern void zxid_conf_redir_to_content_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_redir_to_content_get")]
  public static extern char zxid_conf_redir_to_content_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_remote_user_ena_set")]
  public static extern void zxid_conf_remote_user_ena_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_remote_user_ena_get")]
  public static extern char zxid_conf_remote_user_ena_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_anon_ok_set")]
  public static extern void zxid_conf_anon_ok_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_anon_ok_get")]
  public static extern string zxid_conf_anon_ok_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_required_authnctx_set")]
  public static extern void zxid_conf_required_authnctx_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_required_authnctx_get")]
  public static extern IntPtr zxid_conf_required_authnctx_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_issue_authnctx_pw_set")]
  public static extern void zxid_conf_issue_authnctx_pw_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_issue_authnctx_pw_get")]
  public static extern string zxid_conf_issue_authnctx_pw_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_pref_acs_binding_set")]
  public static extern void zxid_conf_idp_pref_acs_binding_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_pref_acs_binding_get")]
  public static extern string zxid_conf_idp_pref_acs_binding_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_before_slop_set")]
  public static extern void zxid_conf_before_slop_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_before_slop_get")]
  public static extern int zxid_conf_before_slop_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_after_slop_set")]
  public static extern void zxid_conf_after_slop_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_after_slop_get")]
  public static extern int zxid_conf_after_slop_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_timeskew_set")]
  public static extern void zxid_conf_timeskew_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_timeskew_get")]
  public static extern int zxid_conf_timeskew_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_a7nttl_set")]
  public static extern void zxid_conf_a7nttl_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_a7nttl_get")]
  public static extern int zxid_conf_a7nttl_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_pdp_url_set")]
  public static extern void zxid_conf_pdp_url_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_pdp_url_get")]
  public static extern string zxid_conf_pdp_url_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_pdp_call_url_set")]
  public static extern void zxid_conf_pdp_call_url_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_pdp_call_url_get")]
  public static extern string zxid_conf_pdp_call_url_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_xasp_vers_set")]
  public static extern void zxid_conf_xasp_vers_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_xasp_vers_get")]
  public static extern string zxid_conf_xasp_vers_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_need_set")]
  public static extern void zxid_conf_need_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_need_get")]
  public static extern IntPtr zxid_conf_need_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_want_set")]
  public static extern void zxid_conf_want_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_want_get")]
  public static extern IntPtr zxid_conf_want_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_attrsrc_set")]
  public static extern void zxid_conf_attrsrc_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_attrsrc_get")]
  public static extern IntPtr zxid_conf_attrsrc_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_inmap_set")]
  public static extern void zxid_conf_inmap_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_inmap_get")]
  public static extern IntPtr zxid_conf_inmap_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_outmap_set")]
  public static extern void zxid_conf_outmap_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_outmap_get")]
  public static extern IntPtr zxid_conf_outmap_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_pepmap_set")]
  public static extern void zxid_conf_pepmap_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_pepmap_get")]
  public static extern IntPtr zxid_conf_pepmap_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_localpdp_role_permit_set")]
  public static extern void zxid_conf_localpdp_role_permit_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_localpdp_role_permit_get")]
  public static extern IntPtr zxid_conf_localpdp_role_permit_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_localpdp_role_deny_set")]
  public static extern void zxid_conf_localpdp_role_deny_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_localpdp_role_deny_get")]
  public static extern IntPtr zxid_conf_localpdp_role_deny_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_localpdp_idpnid_permit_set")]
  public static extern void zxid_conf_localpdp_idpnid_permit_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_localpdp_idpnid_permit_get")]
  public static extern IntPtr zxid_conf_localpdp_idpnid_permit_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_localpdp_idpnid_deny_set")]
  public static extern void zxid_conf_localpdp_idpnid_deny_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_localpdp_idpnid_deny_get")]
  public static extern IntPtr zxid_conf_localpdp_idpnid_deny_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_max_soap_retry_set")]
  public static extern void zxid_conf_max_soap_retry_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_max_soap_retry_get")]
  public static extern int zxid_conf_max_soap_retry_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_defaultqs_set")]
  public static extern void zxid_conf_defaultqs_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_defaultqs_get")]
  public static extern string zxid_conf_defaultqs_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_mod_saml_attr_prefix_set")]
  public static extern void zxid_conf_mod_saml_attr_prefix_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_mod_saml_attr_prefix_get")]
  public static extern string zxid_conf_mod_saml_attr_prefix_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_page_set")]
  public static extern void zxid_conf_idp_sel_page_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_page_get")]
  public static extern string zxid_conf_idp_sel_page_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_start_set")]
  public static extern void zxid_conf_idp_sel_start_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_start_get")]
  public static extern string zxid_conf_idp_sel_start_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_new_idp_set")]
  public static extern void zxid_conf_idp_sel_new_idp_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_new_idp_get")]
  public static extern string zxid_conf_idp_sel_new_idp_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_our_eid_set")]
  public static extern void zxid_conf_idp_sel_our_eid_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_our_eid_get")]
  public static extern string zxid_conf_idp_sel_our_eid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_tech_user_set")]
  public static extern void zxid_conf_idp_sel_tech_user_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_tech_user_get")]
  public static extern string zxid_conf_idp_sel_tech_user_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_tech_site_set")]
  public static extern void zxid_conf_idp_sel_tech_site_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_tech_site_get")]
  public static extern string zxid_conf_idp_sel_tech_site_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_footer_set")]
  public static extern void zxid_conf_idp_sel_footer_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_footer_get")]
  public static extern string zxid_conf_idp_sel_footer_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_end_set")]
  public static extern void zxid_conf_idp_sel_end_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_idp_sel_end_get")]
  public static extern string zxid_conf_idp_sel_end_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_page_set")]
  public static extern void zxid_conf_an_page_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_page_get")]
  public static extern string zxid_conf_an_page_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_start_set")]
  public static extern void zxid_conf_an_start_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_start_get")]
  public static extern string zxid_conf_an_start_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_our_eid_set")]
  public static extern void zxid_conf_an_our_eid_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_our_eid_get")]
  public static extern string zxid_conf_an_our_eid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_tech_user_set")]
  public static extern void zxid_conf_an_tech_user_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_tech_user_get")]
  public static extern string zxid_conf_an_tech_user_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_tech_site_set")]
  public static extern void zxid_conf_an_tech_site_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_tech_site_get")]
  public static extern string zxid_conf_an_tech_site_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_footer_set")]
  public static extern void zxid_conf_an_footer_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_footer_get")]
  public static extern string zxid_conf_an_footer_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_end_set")]
  public static extern void zxid_conf_an_end_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_an_end_get")]
  public static extern string zxid_conf_an_end_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_mgmt_start_set")]
  public static extern void zxid_conf_mgmt_start_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_mgmt_start_get")]
  public static extern string zxid_conf_mgmt_start_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_mgmt_logout_set")]
  public static extern void zxid_conf_mgmt_logout_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_mgmt_logout_get")]
  public static extern string zxid_conf_mgmt_logout_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_mgmt_defed_set")]
  public static extern void zxid_conf_mgmt_defed_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_mgmt_defed_get")]
  public static extern string zxid_conf_mgmt_defed_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_mgmt_footer_set")]
  public static extern void zxid_conf_mgmt_footer_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_mgmt_footer_get")]
  public static extern string zxid_conf_mgmt_footer_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_mgmt_end_set")]
  public static extern void zxid_conf_mgmt_end_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_mgmt_end_get")]
  public static extern string zxid_conf_mgmt_end_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_dbg_set")]
  public static extern void zxid_conf_dbg_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_dbg_get")]
  public static extern string zxid_conf_dbg_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zxid_conf")]
  public static extern IntPtr new_zxid_conf();

  [DllImport("zxid", EntryPoint="CSharp_delete_zxid_conf")]
  public static extern void delete_zxid_conf(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_magic_set")]
  public static extern void zxid_cgi_magic_set(HandleRef jarg1, uint jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_magic_get")]
  public static extern uint zxid_cgi_magic_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_op_set")]
  public static extern void zxid_cgi_op_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_op_get")]
  public static extern char zxid_cgi_op_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_pr_ix_set")]
  public static extern void zxid_cgi_pr_ix_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_pr_ix_get")]
  public static extern char zxid_cgi_pr_ix_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_allow_create_set")]
  public static extern void zxid_cgi_allow_create_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_allow_create_get")]
  public static extern char zxid_cgi_allow_create_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_ispassive_set")]
  public static extern void zxid_cgi_ispassive_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_ispassive_get")]
  public static extern char zxid_cgi_ispassive_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_force_authn_set")]
  public static extern void zxid_cgi_force_authn_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_force_authn_get")]
  public static extern char zxid_cgi_force_authn_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_enc_hint_set")]
  public static extern void zxid_cgi_enc_hint_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_enc_hint_get")]
  public static extern char zxid_cgi_enc_hint_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_pad6_set")]
  public static extern void zxid_cgi_pad6_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_pad6_get")]
  public static extern char zxid_cgi_pad6_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_pad7_set")]
  public static extern void zxid_cgi_pad7_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_pad7_get")]
  public static extern char zxid_cgi_pad7_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_sid_set")]
  public static extern void zxid_cgi_sid_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_sid_get")]
  public static extern string zxid_cgi_sid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_nid_set")]
  public static extern void zxid_cgi_nid_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_nid_get")]
  public static extern string zxid_cgi_nid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_uid_set")]
  public static extern void zxid_cgi_uid_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_uid_get")]
  public static extern string zxid_cgi_uid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_pw_set")]
  public static extern void zxid_cgi_pw_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_pw_get")]
  public static extern string zxid_cgi_pw_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_ssoreq_set")]
  public static extern void zxid_cgi_ssoreq_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_ssoreq_get")]
  public static extern string zxid_cgi_ssoreq_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_cdc_set")]
  public static extern void zxid_cgi_cdc_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_cdc_get")]
  public static extern string zxid_cgi_cdc_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_eid_set")]
  public static extern void zxid_cgi_eid_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_eid_get")]
  public static extern string zxid_cgi_eid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_nid_fmt_set")]
  public static extern void zxid_cgi_nid_fmt_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_nid_fmt_get")]
  public static extern string zxid_cgi_nid_fmt_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_affil_set")]
  public static extern void zxid_cgi_affil_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_affil_get")]
  public static extern string zxid_cgi_affil_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_consent_set")]
  public static extern void zxid_cgi_consent_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_consent_get")]
  public static extern string zxid_cgi_consent_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_matching_rule_set")]
  public static extern void zxid_cgi_matching_rule_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_matching_rule_get")]
  public static extern string zxid_cgi_matching_rule_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_authn_ctx_set")]
  public static extern void zxid_cgi_authn_ctx_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_authn_ctx_get")]
  public static extern string zxid_cgi_authn_ctx_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_pxy_count_set")]
  public static extern void zxid_cgi_pxy_count_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_pxy_count_get")]
  public static extern string zxid_cgi_pxy_count_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_get_complete_set")]
  public static extern void zxid_cgi_get_complete_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_get_complete_get")]
  public static extern string zxid_cgi_get_complete_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_idppxylist_set")]
  public static extern void zxid_cgi_idppxylist_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_idppxylist_get")]
  public static extern string zxid_cgi_idppxylist_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_rs_set")]
  public static extern void zxid_cgi_rs_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_rs_get")]
  public static extern string zxid_cgi_rs_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_newnym_set")]
  public static extern void zxid_cgi_newnym_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_newnym_get")]
  public static extern string zxid_cgi_newnym_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_saml_art_set")]
  public static extern void zxid_cgi_saml_art_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_saml_art_get")]
  public static extern string zxid_cgi_saml_art_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_saml_resp_set")]
  public static extern void zxid_cgi_saml_resp_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_saml_resp_get")]
  public static extern string zxid_cgi_saml_resp_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_saml_req_set")]
  public static extern void zxid_cgi_saml_req_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_saml_req_get")]
  public static extern string zxid_cgi_saml_req_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_sigalg_set")]
  public static extern void zxid_cgi_sigalg_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_sigalg_get")]
  public static extern string zxid_cgi_sigalg_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_sig_set")]
  public static extern void zxid_cgi_sig_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_sig_get")]
  public static extern string zxid_cgi_sig_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_sigval_set")]
  public static extern void zxid_cgi_sigval_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_sigval_get")]
  public static extern string zxid_cgi_sigval_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_sigmsg_set")]
  public static extern void zxid_cgi_sigmsg_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_sigmsg_get")]
  public static extern string zxid_cgi_sigmsg_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_err_set")]
  public static extern void zxid_cgi_err_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_err_get")]
  public static extern string zxid_cgi_err_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_msg_set")]
  public static extern void zxid_cgi_msg_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_msg_get")]
  public static extern string zxid_cgi_msg_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_dbg_set")]
  public static extern void zxid_cgi_dbg_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_dbg_get")]
  public static extern string zxid_cgi_dbg_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_zxapp_set")]
  public static extern void zxid_cgi_zxapp_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_zxapp_get")]
  public static extern string zxid_cgi_zxapp_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_zxrfr_set")]
  public static extern void zxid_cgi_zxrfr_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_zxrfr_get")]
  public static extern string zxid_cgi_zxrfr_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_ok_set")]
  public static extern void zxid_cgi_ok_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_ok_get")]
  public static extern string zxid_cgi_ok_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_idp_list_set")]
  public static extern void zxid_cgi_idp_list_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cgi_idp_list_get")]
  public static extern IntPtr zxid_cgi_idp_list_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zxid_cgi")]
  public static extern IntPtr new_zxid_cgi();

  [DllImport("zxid", EntryPoint="CSharp_delete_zxid_cgi")]
  public static extern void delete_zxid_cgi(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_magic_set")]
  public static extern void zxid_ses_magic_set(HandleRef jarg1, uint jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_magic_get")]
  public static extern uint zxid_ses_magic_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_sid_set")]
  public static extern void zxid_ses_sid_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_sid_get")]
  public static extern string zxid_ses_sid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_uid_set")]
  public static extern void zxid_ses_uid_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_uid_get")]
  public static extern string zxid_ses_uid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_nid_set")]
  public static extern void zxid_ses_nid_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_nid_get")]
  public static extern string zxid_ses_nid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_tgt_set")]
  public static extern void zxid_ses_tgt_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_tgt_get")]
  public static extern string zxid_ses_tgt_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_sesix_set")]
  public static extern void zxid_ses_sesix_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_sesix_get")]
  public static extern string zxid_ses_sesix_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_msgid_set")]
  public static extern void zxid_ses_msgid_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_msgid_get")]
  public static extern string zxid_ses_msgid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_an_ctx_set")]
  public static extern void zxid_ses_an_ctx_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_an_ctx_get")]
  public static extern string zxid_ses_an_ctx_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_nidfmt_set")]
  public static extern void zxid_ses_nidfmt_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_nidfmt_get")]
  public static extern char zxid_ses_nidfmt_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_tgtfmt_set")]
  public static extern void zxid_ses_tgtfmt_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_tgtfmt_get")]
  public static extern char zxid_ses_tgtfmt_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_sigres_set")]
  public static extern void zxid_ses_sigres_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_sigres_get")]
  public static extern char zxid_ses_sigres_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_pad3_set")]
  public static extern void zxid_ses_pad3_set(HandleRef jarg1, char jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_pad3_get")]
  public static extern char zxid_ses_pad3_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_sso_a7n_path_set")]
  public static extern void zxid_ses_sso_a7n_path_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_sso_a7n_path_get")]
  public static extern string zxid_ses_sso_a7n_path_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_tgt_a7n_path_set")]
  public static extern void zxid_ses_tgt_a7n_path_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_tgt_a7n_path_get")]
  public static extern string zxid_ses_tgt_a7n_path_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_setcookie_set")]
  public static extern void zxid_ses_setcookie_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_setcookie_get")]
  public static extern string zxid_ses_setcookie_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_cookie_set")]
  public static extern void zxid_ses_cookie_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_cookie_get")]
  public static extern string zxid_ses_cookie_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_rs_set")]
  public static extern void zxid_ses_rs_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_rs_get")]
  public static extern string zxid_ses_rs_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_nameid_set")]
  public static extern void zxid_ses_nameid_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_nameid_get")]
  public static extern IntPtr zxid_ses_nameid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_a7n_set")]
  public static extern void zxid_ses_a7n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_a7n_get")]
  public static extern IntPtr zxid_ses_a7n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_tgta7n_set")]
  public static extern void zxid_ses_tgta7n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_tgta7n_get")]
  public static extern IntPtr zxid_ses_tgta7n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_a7n11_set")]
  public static extern void zxid_ses_a7n11_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_a7n11_get")]
  public static extern IntPtr zxid_ses_a7n11_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_tgta7n11_set")]
  public static extern void zxid_ses_tgta7n11_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_tgta7n11_get")]
  public static extern IntPtr zxid_ses_tgta7n11_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_a7n12_set")]
  public static extern void zxid_ses_a7n12_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_a7n12_get")]
  public static extern IntPtr zxid_ses_a7n12_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_tgta7n12_set")]
  public static extern void zxid_ses_tgta7n12_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_tgta7n12_get")]
  public static extern IntPtr zxid_ses_tgta7n12_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_sesbuf_set")]
  public static extern void zxid_ses_sesbuf_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_sesbuf_get")]
  public static extern string zxid_ses_sesbuf_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_sso_a7n_buf_set")]
  public static extern void zxid_ses_sso_a7n_buf_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_sso_a7n_buf_get")]
  public static extern string zxid_ses_sso_a7n_buf_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_at_set")]
  public static extern void zxid_ses_at_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_at_get")]
  public static extern IntPtr zxid_ses_at_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zxid_ses")]
  public static extern IntPtr new_zxid_ses();

  [DllImport("zxid", EntryPoint="CSharp_delete_zxid_ses")]
  public static extern void delete_zxid_ses(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_n_set")]
  public static extern void zxid_attr_n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_n_get")]
  public static extern IntPtr zxid_attr_n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_nv_set")]
  public static extern void zxid_attr_nv_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_nv_get")]
  public static extern IntPtr zxid_attr_nv_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_name_set")]
  public static extern void zxid_attr_name_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_name_get")]
  public static extern string zxid_attr_name_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_val_set")]
  public static extern void zxid_attr_val_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_val_get")]
  public static extern string zxid_attr_val_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_map_val_set")]
  public static extern void zxid_attr_map_val_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_map_val_get")]
  public static extern IntPtr zxid_attr_map_val_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_orig_set")]
  public static extern void zxid_attr_orig_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_orig_get")]
  public static extern IntPtr zxid_attr_orig_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_issuer_set")]
  public static extern void zxid_attr_issuer_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_attr_issuer_get")]
  public static extern IntPtr zxid_attr_issuer_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zxid_attr")]
  public static extern IntPtr new_zxid_attr();

  [DllImport("zxid", EntryPoint="CSharp_delete_zxid_attr")]
  public static extern void delete_zxid_attr(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_need_n_set")]
  public static extern void zxid_need_n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_need_n_get")]
  public static extern IntPtr zxid_need_n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_need_at_set")]
  public static extern void zxid_need_at_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_need_at_get")]
  public static extern IntPtr zxid_need_at_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_need_usage_set")]
  public static extern void zxid_need_usage_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_need_usage_get")]
  public static extern string zxid_need_usage_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_need_retent_set")]
  public static extern void zxid_need_retent_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_need_retent_get")]
  public static extern string zxid_need_retent_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_need_oblig_set")]
  public static extern void zxid_need_oblig_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_need_oblig_get")]
  public static extern string zxid_need_oblig_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_need_ext_set")]
  public static extern void zxid_need_ext_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_need_ext_get")]
  public static extern string zxid_need_ext_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zxid_need")]
  public static extern IntPtr new_zxid_need();

  [DllImport("zxid", EntryPoint="CSharp_delete_zxid_need")]
  public static extern void delete_zxid_need(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_n_set")]
  public static extern void zxid_map_n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_n_get")]
  public static extern IntPtr zxid_map_n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_rule_set")]
  public static extern void zxid_map_rule_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_rule_get")]
  public static extern int zxid_map_rule_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_ns_set")]
  public static extern void zxid_map_ns_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_ns_get")]
  public static extern string zxid_map_ns_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_src_set")]
  public static extern void zxid_map_src_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_src_get")]
  public static extern string zxid_map_src_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_dst_set")]
  public static extern void zxid_map_dst_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_dst_get")]
  public static extern string zxid_map_dst_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_ext_set")]
  public static extern void zxid_map_ext_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_ext_get")]
  public static extern string zxid_map_ext_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zxid_map")]
  public static extern IntPtr new_zxid_map();

  [DllImport("zxid", EntryPoint="CSharp_delete_zxid_map")]
  public static extern void delete_zxid_map(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cstr_list_n_set")]
  public static extern void zxid_cstr_list_n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cstr_list_n_get")]
  public static extern IntPtr zxid_cstr_list_n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cstr_list_s_set")]
  public static extern void zxid_cstr_list_s_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cstr_list_s_get")]
  public static extern string zxid_cstr_list_s_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zxid_cstr_list")]
  public static extern IntPtr new_zxid_cstr_list();

  [DllImport("zxid", EntryPoint="CSharp_delete_zxid_cstr_list")]
  public static extern void delete_zxid_cstr_list(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAP_RULE_RENAME_get")]
  public static extern int ZXID_MAP_RULE_RENAME_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAP_RULE_DEL_get")]
  public static extern int ZXID_MAP_RULE_DEL_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAP_RULE_RESET_get")]
  public static extern int ZXID_MAP_RULE_RESET_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAP_RULE_FEIDEDEC_get")]
  public static extern int ZXID_MAP_RULE_FEIDEDEC_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAP_RULE_FEIDEENC_get")]
  public static extern int ZXID_MAP_RULE_FEIDEENC_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAP_RULE_UNSB64_INF_get")]
  public static extern int ZXID_MAP_RULE_UNSB64_INF_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAP_RULE_DEF_SB64_get")]
  public static extern int ZXID_MAP_RULE_DEF_SB64_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAP_RULE_UNSB64_get")]
  public static extern int ZXID_MAP_RULE_UNSB64_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAP_RULE_SB64_get")]
  public static extern int ZXID_MAP_RULE_SB64_get();

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_n_set")]
  public static extern void zxid_atsrc_n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_n_get")]
  public static extern IntPtr zxid_atsrc_n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_at_set")]
  public static extern void zxid_atsrc_at_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_at_get")]
  public static extern IntPtr zxid_atsrc_at_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_ns_set")]
  public static extern void zxid_atsrc_ns_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_ns_get")]
  public static extern string zxid_atsrc_ns_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_weight_set")]
  public static extern void zxid_atsrc_weight_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_weight_get")]
  public static extern string zxid_atsrc_weight_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_url_set")]
  public static extern void zxid_atsrc_url_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_url_get")]
  public static extern string zxid_atsrc_url_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_aapml_set")]
  public static extern void zxid_atsrc_aapml_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_aapml_get")]
  public static extern string zxid_atsrc_aapml_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_otherlim_set")]
  public static extern void zxid_atsrc_otherlim_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_otherlim_get")]
  public static extern string zxid_atsrc_otherlim_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_ext_set")]
  public static extern void zxid_atsrc_ext_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_atsrc_ext_get")]
  public static extern string zxid_atsrc_ext_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zxid_atsrc")]
  public static extern IntPtr new_zxid_atsrc();

  [DllImport("zxid", EntryPoint="CSharp_delete_zxid_atsrc")]
  public static extern void delete_zxid_atsrc(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SES_DIR_get")]
  public static extern string ZXID_SES_DIR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_USER_DIR_get")]
  public static extern string ZXID_USER_DIR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_UID_DIR_get")]
  public static extern string ZXID_UID_DIR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_NID_DIR_get")]
  public static extern string ZXID_NID_DIR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_PEM_DIR_get")]
  public static extern string ZXID_PEM_DIR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_COT_DIR_get")]
  public static extern string ZXID_COT_DIR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_DIMD_DIR_get")]
  public static extern string ZXID_DIMD_DIR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAX_USER_get")]
  public static extern int ZXID_MAX_USER_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAX_MD_get")]
  public static extern int ZXID_MAX_MD_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAX_SOAP_get")]
  public static extern int ZXID_MAX_SOAP_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAX_EID_get")]
  public static extern int ZXID_MAX_EID_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MAX_DIR_get")]
  public static extern int ZXID_MAX_DIR_get();

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_n_set")]
  public static extern void zxid_entity_n_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_n_get")]
  public static extern IntPtr zxid_entity_n_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_n_cdc_set")]
  public static extern void zxid_entity_n_cdc_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_n_cdc_get")]
  public static extern IntPtr zxid_entity_n_cdc_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_eid_len_set")]
  public static extern void zxid_entity_eid_len_set(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_eid_len_get")]
  public static extern int zxid_entity_eid_len_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_eid_set")]
  public static extern void zxid_entity_eid_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_eid_get")]
  public static extern string zxid_entity_eid_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_sha1_name_set")]
  public static extern void zxid_entity_sha1_name_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_sha1_name_get")]
  public static extern string zxid_entity_sha1_name_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_tls_cert_set")]
  public static extern void zxid_entity_tls_cert_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_tls_cert_get")]
  public static extern IntPtr zxid_entity_tls_cert_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_sign_cert_set")]
  public static extern void zxid_entity_sign_cert_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_sign_cert_get")]
  public static extern IntPtr zxid_entity_sign_cert_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_enc_cert_set")]
  public static extern void zxid_entity_enc_cert_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_enc_cert_get")]
  public static extern IntPtr zxid_entity_enc_cert_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_ed_set")]
  public static extern void zxid_entity_ed_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_entity_ed_get")]
  public static extern IntPtr zxid_entity_ed_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zxid_entity")]
  public static extern IntPtr new_zxid_entity();

  [DllImport("zxid", EntryPoint="CSharp_delete_zxid_entity")]
  public static extern void delete_zxid_entity(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_EXIT_get")]
  public static extern int ZXID_AUTO_EXIT_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_REDIR_get")]
  public static extern int ZXID_AUTO_REDIR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_SOAPC_get")]
  public static extern int ZXID_AUTO_SOAPC_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_SOAPH_get")]
  public static extern int ZXID_AUTO_SOAPH_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_METAC_get")]
  public static extern int ZXID_AUTO_METAC_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_METAH_get")]
  public static extern int ZXID_AUTO_METAH_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_LOGINC_get")]
  public static extern int ZXID_AUTO_LOGINC_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_LOGINH_get")]
  public static extern int ZXID_AUTO_LOGINH_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_MGMTC_get")]
  public static extern int ZXID_AUTO_MGMTC_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_MGMTH_get")]
  public static extern int ZXID_AUTO_MGMTH_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_FORMF_get")]
  public static extern int ZXID_AUTO_FORMF_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_FORMT_get")]
  public static extern int ZXID_AUTO_FORMT_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_ALL_get")]
  public static extern int ZXID_AUTO_ALL_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_DEBUG_get")]
  public static extern int ZXID_AUTO_DEBUG_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_FMTQ_get")]
  public static extern int ZXID_AUTO_FMTQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_AUTO_FMTJ_get")]
  public static extern int ZXID_AUTO_FMTJ_get();

  [DllImport("zxid", EntryPoint="CSharp_zxid_simple")]
  public static extern string zxid_simple(string jarg1, string jarg2, int jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_list")]
  public static extern string zxid_idp_list(string jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_select")]
  public static extern string zxid_idp_select(string jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_fed_mgmt")]
  public static extern string zxid_fed_mgmt(string jarg1, string jarg2, int jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_new_conf_to_cf")]
  public static extern IntPtr zxid_new_conf_to_cf(string jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_simple_cf")]
  public static extern string zxid_simple_cf(HandleRef jarg1, int jarg2, string jarg3, HandleRef jarg4, int jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_list_cf")]
  public static extern string zxid_idp_list_cf(HandleRef jarg1, HandleRef jarg2, int jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_select_cf")]
  public static extern string zxid_idp_select_cf(HandleRef jarg1, HandleRef jarg2, int jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_fed_mgmt_cf")]
  public static extern string zxid_fed_mgmt_cf(HandleRef jarg1, HandleRef jarg2, int jarg3, string jarg4, int jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_conf_to_cf_len")]
  public static extern int zxid_conf_to_cf_len(HandleRef jarg1, int jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_simple_len")]
  public static extern string zxid_simple_len(int jarg1, string jarg2, int jarg3, string jarg4, HandleRef jarg5, int jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_list_len")]
  public static extern string zxid_idp_list_len(int jarg1, string jarg2, HandleRef jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_select_len")]
  public static extern string zxid_idp_select_len(int jarg1, string jarg2, HandleRef jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_fed_mgmt_len")]
  public static extern string zxid_fed_mgmt_len(int jarg1, string jarg2, HandleRef jarg3, string jarg4, int jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_select_zxstr_cf")]
  public static extern IntPtr zxid_idp_select_zxstr_cf(HandleRef jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_simple_ab_pep")]
  public static extern string zxid_simple_ab_pep(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_simple_ses_active_cf")]
  public static extern string zxid_simple_ses_active_cf(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, int jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_simple_no_ses_cf")]
  public static extern string zxid_simple_no_ses_cf(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, int jarg5);

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SSO_SIGN_A7N_get")]
  public static extern int ZXID_SSO_SIGN_A7N_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SSO_SIGN_RESP_get")]
  public static extern int ZXID_SSO_SIGN_RESP_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SSO_SIGN_A7N_SIMPLE_get")]
  public static extern int ZXID_SSO_SIGN_A7N_SIMPLE_get();

  [DllImport("zxid", EntryPoint="CSharp_zxsig_ref_sref_set")]
  public static extern void zxsig_ref_sref_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxsig_ref_sref_get")]
  public static extern IntPtr zxsig_ref_sref_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxsig_ref_blob_set")]
  public static extern void zxsig_ref_blob_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxsig_ref_blob_get")]
  public static extern IntPtr zxsig_ref_blob_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxsig_ref_id_set")]
  public static extern void zxsig_ref_id_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxsig_ref_id_get")]
  public static extern IntPtr zxsig_ref_id_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxsig_ref_canon_set")]
  public static extern void zxsig_ref_canon_set(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxsig_ref_canon_get")]
  public static extern IntPtr zxsig_ref_canon_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zxsig_ref")]
  public static extern IntPtr new_zxsig_ref();

  [DllImport("zxid", EntryPoint="CSharp_delete_zxsig_ref")]
  public static extern void delete_zxsig_ref(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_ZXSIG_OK_get")]
  public static extern int ZXSIG_OK_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXSIG_BAD_DALGO_get")]
  public static extern int ZXSIG_BAD_DALGO_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXSIG_DIGEST_LEN_get")]
  public static extern int ZXSIG_DIGEST_LEN_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXSIG_BAD_DIGEST_get")]
  public static extern int ZXSIG_BAD_DIGEST_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXSIG_BAD_SALGO_get")]
  public static extern int ZXSIG_BAD_SALGO_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXSIG_BAD_CERT_get")]
  public static extern int ZXSIG_BAD_CERT_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXSIG_VFY_FAIL_get")]
  public static extern int ZXSIG_VFY_FAIL_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXSIG_NO_SIG_get")]
  public static extern int ZXSIG_NO_SIG_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXSIG_TIMEOUT_get")]
  public static extern int ZXSIG_TIMEOUT_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXSIG_AUDIENCE_get")]
  public static extern int ZXSIG_AUDIENCE_get();

  [DllImport("zxid", EntryPoint="CSharp_zxsig_sign")]
  public static extern IntPtr zxsig_sign(HandleRef jarg1, int jarg2, HandleRef jarg3, HandleRef jarg4, HandleRef jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxsig_validate")]
  public static extern int zxsig_validate(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, int jarg4, HandleRef jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxsig_data_rsa_sha1")]
  public static extern int zxsig_data_rsa_sha1(HandleRef jarg1, int jarg2, string jarg3, HandleRef jarg4, HandleRef jarg5, string jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxsig_verify_data_rsa_sha1")]
  public static extern int zxsig_verify_data_rsa_sha1(int jarg1, string jarg2, int jarg3, string jarg4, HandleRef jarg5, string jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxenc_symkey_dec")]
  public static extern IntPtr zxenc_symkey_dec(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxenc_privkey_dec")]
  public static extern IntPtr zxenc_privkey_dec(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxenc_symkey_enc")]
  public static extern IntPtr zxenc_symkey_enc(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, HandleRef jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxenc_pubkey_enc")]
  public static extern IntPtr zxenc_pubkey_enc(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, string jarg5);

  [DllImport("zxid", EntryPoint="CSharp_ZXLOG_RELY_DIR_get")]
  public static extern string ZXLOG_RELY_DIR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXLOG_ISSUE_DIR_get")]
  public static extern string ZXLOG_ISSUE_DIR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXLOG_A7N_KIND_get")]
  public static extern string ZXLOG_A7N_KIND_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXLOG_MSG_KIND_get")]
  public static extern string ZXLOG_MSG_KIND_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXLOG_WIR_KIND_get")]
  public static extern string ZXLOG_WIR_KIND_get();

  [DllImport("zxid", EntryPoint="CSharp_zxlog_write_line")]
  public static extern void zxlog_write_line(HandleRef jarg1, string jarg2, int jarg3, int jarg4, string jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxlog_path")]
  public static extern IntPtr zxlog_path(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, string jarg4, string jarg5, int jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxlog_dup_check")]
  public static extern int zxlog_dup_check(HandleRef jarg1, HandleRef jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxlog_blob")]
  public static extern int zxlog_blob(HandleRef jarg1, int jarg2, HandleRef jarg3, HandleRef jarg4, string jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxlog")]
  public static extern int zxlog(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, string jarg4, HandleRef jarg5, HandleRef jarg6, HandleRef jarg7, HandleRef jarg8, string jarg9, string jarg10, string jarg11, string jarg12, string jarg13);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_ent_from_file")]
  public static extern IntPtr zxid_get_ent_from_file(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_ent_from_cache")]
  public static extern IntPtr zxid_get_ent_from_cache(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_write_ent_to_cache")]
  public static extern int zxid_write_ent_to_cache(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_parse_meta")]
  public static extern IntPtr zxid_parse_meta(HandleRef jarg1, HandleRef jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_meta_ss")]
  public static extern IntPtr zxid_get_meta_ss(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_meta")]
  public static extern IntPtr zxid_get_meta(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_ent_ss")]
  public static extern IntPtr zxid_get_ent_ss(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_ent")]
  public static extern IntPtr zxid_get_ent(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_ent_by_succinct_id")]
  public static extern IntPtr zxid_get_ent_by_succinct_id(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_ent_by_sha1_name")]
  public static extern IntPtr zxid_get_ent_by_sha1_name(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_load_cot_cache")]
  public static extern IntPtr zxid_load_cot_cache(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_key_info")]
  public static extern IntPtr zxid_key_info(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_key_desc")]
  public static extern IntPtr zxid_key_desc(HandleRef jarg1, string jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ar_desc")]
  public static extern IntPtr zxid_ar_desc(HandleRef jarg1, string jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sso_desc")]
  public static extern IntPtr zxid_sso_desc(HandleRef jarg1, string jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_slo_desc")]
  public static extern IntPtr zxid_slo_desc(HandleRef jarg1, string jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mni_desc")]
  public static extern IntPtr zxid_mni_desc(HandleRef jarg1, string jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ac_desc")]
  public static extern IntPtr zxid_ac_desc(HandleRef jarg1, string jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_sso_desc")]
  public static extern IntPtr zxid_idp_sso_desc(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_sso_desc")]
  public static extern IntPtr zxid_sp_sso_desc(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_meta")]
  public static extern IntPtr zxid_sp_meta(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_send_sp_meta")]
  public static extern int zxid_send_sp_meta(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_carml")]
  public static extern IntPtr zxid_sp_carml(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_my_entity_id")]
  public static extern IntPtr zxid_my_entity_id(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_my_cdc_url")]
  public static extern IntPtr zxid_my_cdc_url(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_my_issuer")]
  public static extern IntPtr zxid_my_issuer(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sha1_file")]
  public static extern void zxid_sha1_file(HandleRef jarg1, string jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_extract_cert")]
  public static extern IntPtr zxid_extract_cert(string jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_extract_private_key")]
  public static extern IntPtr zxid_extract_private_key(string jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_read_cert")]
  public static extern IntPtr zxid_read_cert(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_read_private_key")]
  public static extern IntPtr zxid_read_private_key(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_set_opt")]
  public static extern int zxid_set_opt(HandleRef jarg1, int jarg2, int jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_set_opt_cstr")]
  public static extern string zxid_set_opt_cstr(HandleRef jarg1, int jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_url_set")]
  public static extern void zxid_url_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_init_conf")]
  public static extern int zxid_init_conf(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_init_conf_ctx")]
  public static extern IntPtr zxid_init_conf_ctx(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_new_conf")]
  public static extern IntPtr zxid_new_conf(string jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_parse_conf_raw")]
  public static extern int zxid_parse_conf_raw(HandleRef jarg1, int jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_parse_conf")]
  public static extern int zxid_parse_conf(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_self_sig_cert")]
  public static extern int zxid_mk_self_sig_cert(HandleRef jarg1, int jarg2, string jarg3, string jarg4, string jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_load_map")]
  public static extern IntPtr zxid_load_map(HandleRef jarg1, HandleRef jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_load_need")]
  public static extern IntPtr zxid_load_need(HandleRef jarg1, HandleRef jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_load_atsrc")]
  public static extern IntPtr zxid_load_atsrc(HandleRef jarg1, HandleRef jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_new_at")]
  public static extern IntPtr zxid_new_at(HandleRef jarg1, HandleRef jarg2, int jarg3, string jarg4, int jarg5, string jarg6, string jarg7);

  [DllImport("zxid", EntryPoint="CSharp_zxid_load_cstr_list")]
  public static extern IntPtr zxid_load_cstr_list(HandleRef jarg1, HandleRef jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_is_needed")]
  public static extern IntPtr zxid_is_needed(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_find_map")]
  public static extern IntPtr zxid_find_map(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_find_cstr_list")]
  public static extern IntPtr zxid_find_cstr_list(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_find_at")]
  public static extern IntPtr zxid_find_at(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_show_conf")]
  public static extern IntPtr zxid_show_conf(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_parse_cgi")]
  public static extern int zxid_parse_cgi(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_new_cgi")]
  public static extern IntPtr zxid_new_cgi(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_sid_from_cookie")]
  public static extern void zxid_get_sid_from_cookie(HandleRef jarg1, HandleRef jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_alloc_ses")]
  public static extern IntPtr zxid_alloc_ses(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_fetch_ses")]
  public static extern IntPtr zxid_fetch_ses(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_ses")]
  public static extern int zxid_get_ses(HandleRef jarg1, HandleRef jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_put_ses")]
  public static extern int zxid_put_ses(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_del_ses")]
  public static extern int zxid_del_ses(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_ses_sso_a7n")]
  public static extern int zxid_get_ses_sso_a7n(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_ses_idp")]
  public static extern IntPtr zxid_get_ses_idp(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_find_ses")]
  public static extern int zxid_find_ses(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_pool_to_ldif")]
  public static extern IntPtr zxid_pool_to_ldif(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_pool_to_json")]
  public static extern IntPtr zxid_pool_to_json(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_pool_to_qs")]
  public static extern IntPtr zxid_pool_to_qs(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_ses_to_pool")]
  public static extern void zxid_ses_to_pool(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_add_attr_to_pool")]
  public static extern void zxid_add_attr_to_pool(HandleRef jarg1, HandleRef jarg2, string jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_add_qs_to_pool")]
  public static extern int zxid_add_qs_to_pool(HandleRef jarg1, HandleRef jarg2, string jarg3, int jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_parse_mni")]
  public static extern IntPtr zxid_parse_mni(HandleRef jarg1, string jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_put_user")]
  public static extern int zxid_put_user(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, HandleRef jarg5, string jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_user_nameid")]
  public static extern IntPtr zxid_get_user_nameid(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_user_change_nameid")]
  public static extern void zxid_user_change_nameid(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_pw_authn")]
  public static extern int zxid_pw_authn(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_version")]
  public static extern int zxid_version();

  [DllImport("zxid", EntryPoint="CSharp_zxid_version_str")]
  public static extern string zxid_version_str();

  [DllImport("zxid", EntryPoint="CSharp_zxid_date_time")]
  public static extern IntPtr zxid_date_time(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_id")]
  public static extern IntPtr zxid_mk_id(HandleRef jarg1, string jarg2, int jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_soap_call_raw")]
  public static extern IntPtr zxid_soap_call_raw(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_lecp_check")]
  public static extern IntPtr zxid_lecp_check(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cdc_read")]
  public static extern int zxid_cdc_read(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cdc_check")]
  public static extern int zxid_cdc_check(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_soap_call_envelope")]
  public static extern IntPtr zxid_soap_call_envelope(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_soap_call_hdr_body")]
  public static extern IntPtr zxid_soap_call_hdr_body(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_soap_call_body")]
  public static extern IntPtr zxid_soap_call_body(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_soap_cgi_resp_body")]
  public static extern int zxid_soap_cgi_resp_body(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_saml2_post_enc")]
  public static extern IntPtr zxid_saml2_post_enc(HandleRef jarg1, string jarg2, HandleRef jarg3, string jarg4, int jarg5, HandleRef jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_saml2_redir_enc")]
  public static extern IntPtr zxid_saml2_redir_enc(HandleRef jarg1, string jarg2, HandleRef jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_saml2_redir_url")]
  public static extern IntPtr zxid_saml2_redir_url(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_saml2_redir")]
  public static extern IntPtr zxid_saml2_redir(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_saml2_resp_redir")]
  public static extern IntPtr zxid_saml2_resp_redir(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_saml_ok")]
  public static extern int zxid_saml_ok(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_decrypt_nameid")]
  public static extern IntPtr zxid_decrypt_nameid(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_decrypt_newnym")]
  public static extern IntPtr zxid_decrypt_newnym(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_chk_sig")]
  public static extern int zxid_chk_sig(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, HandleRef jarg5, HandleRef jarg6, string jarg7);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_val")]
  public static extern IntPtr zxid_map_val(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_loc_raw")]
  public static extern IntPtr zxid_idp_loc_raw(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, int jarg4, string jarg5, int jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_loc")]
  public static extern IntPtr zxid_idp_loc(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, int jarg5, string jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_soap")]
  public static extern IntPtr zxid_idp_soap(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, int jarg5, HandleRef jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_loc_by_index_raw")]
  public static extern IntPtr zxid_sp_loc_by_index_raw(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, int jarg4, HandleRef jarg5, HandleRef jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_loc_raw")]
  public static extern IntPtr zxid_sp_loc_raw(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, int jarg4, string jarg5, int jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_loc")]
  public static extern IntPtr zxid_sp_loc(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, int jarg5, string jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_soap")]
  public static extern IntPtr zxid_sp_soap(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, int jarg5, HandleRef jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_decode_redir_or_post")]
  public static extern IntPtr zxid_decode_redir_or_post(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_dispatch")]
  public static extern IntPtr zxid_sp_dispatch(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_soap_dispatch")]
  public static extern int zxid_sp_soap_dispatch(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_soap_parse")]
  public static extern int zxid_sp_soap_parse(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, int jarg4, string jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_dec_a7n")]
  public static extern IntPtr zxid_dec_a7n(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_dispatch")]
  public static extern IntPtr zxid_idp_dispatch(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_soap_dispatch")]
  public static extern int zxid_idp_soap_dispatch(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_soap_parse")]
  public static extern int zxid_idp_soap_parse(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, int jarg4, string jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_anoint_a7n")]
  public static extern int zxid_anoint_a7n(HandleRef jarg1, int jarg2, HandleRef jarg3, HandleRef jarg4, string jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_add_ldif_attrs")]
  public static extern IntPtr zxid_add_ldif_attrs(HandleRef jarg1, HandleRef jarg2, int jarg3, string jarg4, string jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_gen_bootstraps")]
  public static extern IntPtr zxid_gen_bootstraps(HandleRef jarg1, string jarg2, string jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_user_a7n_to_sp")]
  public static extern IntPtr zxid_mk_user_a7n_to_sp(HandleRef jarg1, HandleRef jarg2, string jarg3, HandleRef jarg4, HandleRef jarg5, string jarg6, int jarg7);

  [DllImport("zxid", EntryPoint="CSharp_zxid_check_fed")]
  public static extern IntPtr zxid_check_fed(HandleRef jarg1, HandleRef jarg2, string jarg3, char jarg4, HandleRef jarg5, HandleRef jarg6, HandleRef jarg7, string jarg8);

  [DllImport("zxid", EntryPoint="CSharp_zxid_add_fed_tok_to_epr")]
  public static extern string zxid_add_fed_tok_to_epr(HandleRef jarg1, HandleRef jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_sso")]
  public static extern IntPtr zxid_idp_sso(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_as_do")]
  public static extern IntPtr zxid_idp_as_do(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_pick_sso_profile")]
  public static extern int zxid_pick_sso_profile(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_start_sso")]
  public static extern int zxid_start_sso(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_start_sso_url")]
  public static extern IntPtr zxid_start_sso_url(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_start_sso_location")]
  public static extern IntPtr zxid_start_sso_location(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_deref_art")]
  public static extern int zxid_sp_deref_art(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_sso_finalize")]
  public static extern int zxid_sp_sso_finalize(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_anon_finalize")]
  public static extern int zxid_sp_anon_finalize(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_saml2_map_nid_fmt")]
  public static extern string zxid_saml2_map_nid_fmt(string jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_saml2_map_protocol_binding")]
  public static extern string zxid_saml2_map_protocol_binding(string jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_protocol_binding_map_saml2")]
  public static extern int zxid_protocol_binding_map_saml2(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_saml2_map_authn_ctx")]
  public static extern string zxid_saml2_map_authn_ctx(string jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_issuer")]
  public static extern IntPtr zxid_issuer(HandleRef jarg1, HandleRef jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sigres_map")]
  public static extern void zxid_sigres_map(int jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_validate_cond")]
  public static extern int zxid_validate_cond(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, HandleRef jarg5, HandleRef jarg6, HandleRef jarg7);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_slo_soap")]
  public static extern int zxid_sp_slo_soap(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_slo_redir")]
  public static extern IntPtr zxid_sp_slo_redir(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_slo_do")]
  public static extern int zxid_sp_slo_do(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_idp_slo_do")]
  public static extern int zxid_idp_slo_do(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_slo_resp_redir")]
  public static extern IntPtr zxid_slo_resp_redir(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_mni_soap")]
  public static extern int zxid_sp_mni_soap(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_sp_mni_redir")]
  public static extern IntPtr zxid_sp_mni_redir(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mni_do")]
  public static extern IntPtr zxid_mni_do(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mni_do_ss")]
  public static extern IntPtr zxid_mni_do_ss(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, HandleRef jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_pep_az_soap")]
  public static extern int zxid_pep_az_soap(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_az_cf_ses")]
  public static extern int zxid_az_cf_ses(HandleRef jarg1, string jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_az_cf")]
  public static extern int zxid_az_cf(HandleRef jarg1, string jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_az")]
  public static extern int zxid_az(string jarg1, string jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_find_attribute")]
  public static extern IntPtr zxid_find_attribute(HandleRef jarg1, int jarg2, string jarg3, int jarg4, string jarg5, int jarg6, string jarg7, int jarg8);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_authn_req")]
  public static extern IntPtr zxid_mk_authn_req(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_art_deref")]
  public static extern IntPtr zxid_mk_art_deref(HandleRef jarg1, HandleRef jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_Status")]
  public static extern IntPtr zxid_mk_Status(HandleRef jarg1, string jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_OK")]
  public static extern IntPtr zxid_OK(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_enc_id")]
  public static extern IntPtr zxid_mk_enc_id(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_enc_a7n")]
  public static extern IntPtr zxid_mk_enc_a7n(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_logout")]
  public static extern IntPtr zxid_mk_logout(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_logout_resp")]
  public static extern IntPtr zxid_mk_logout_resp(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_mni")]
  public static extern IntPtr zxid_mk_mni(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_mni_resp")]
  public static extern IntPtr zxid_mk_mni_resp(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_a7n")]
  public static extern IntPtr zxid_mk_a7n(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, HandleRef jarg5, HandleRef jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_subj")]
  public static extern IntPtr zxid_mk_subj(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_an_stmt")]
  public static extern IntPtr zxid_mk_an_stmt(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_saml_resp")]
  public static extern IntPtr zxid_mk_saml_resp(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_xacml_resp")]
  public static extern IntPtr zxid_mk_xacml_resp(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_xacml_simple_at")]
  public static extern IntPtr zxid_mk_xacml_simple_at(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, HandleRef jarg5, HandleRef jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_az")]
  public static extern IntPtr zxid_mk_az(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, HandleRef jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_az_cd1")]
  public static extern IntPtr zxid_mk_az_cd1(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4, HandleRef jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_attribute")]
  public static extern IntPtr zxid_mk_attribute(HandleRef jarg1, string jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_lu_Status")]
  public static extern IntPtr zxid_mk_lu_Status(HandleRef jarg1, string jarg2, string jarg3, string jarg4, string jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_di_query")]
  public static extern IntPtr zxid_mk_di_query(HandleRef jarg1, string jarg2, string jarg3, string jarg4, string jarg5);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_addr")]
  public static extern IntPtr zxid_mk_addr(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_dap_select")]
  public static extern IntPtr zxid_mk_dap_select(HandleRef jarg1, string jarg2, string jarg3, string jarg4, int jarg5, int jarg6, int jarg7, int jarg8, int jarg9);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_dap_query_item")]
  public static extern IntPtr zxid_mk_dap_query_item(HandleRef jarg1, HandleRef jarg2, string jarg3, string jarg4, string jarg5, string jarg6, int jarg7, int jarg8, int jarg9, string jarg10, string jarg11, string jarg12);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_dap_testop")]
  public static extern IntPtr zxid_mk_dap_testop(HandleRef jarg1, string jarg2, string jarg3, string jarg4, int jarg5, int jarg6, int jarg7, int jarg8, int jarg9);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_dap_test_item")]
  public static extern IntPtr zxid_mk_dap_test_item(HandleRef jarg1, HandleRef jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_dap_resquery")]
  public static extern IntPtr zxid_mk_dap_resquery(HandleRef jarg1, HandleRef jarg2, string jarg3, string jarg4, string jarg5, string jarg6, int jarg7, string jarg8);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_dap_subscription")]
  public static extern IntPtr zxid_mk_dap_subscription(HandleRef jarg1, string jarg2, string jarg3, HandleRef jarg4, string jarg5, string jarg6, string jarg7, string jarg8, int jarg9, string jarg10, string jarg11);

  [DllImport("zxid", EntryPoint="CSharp_zxid_mk_dap_query")]
  public static extern IntPtr zxid_mk_dap_query(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_wsp_validate")]
  public static extern string zxid_wsp_validate(HandleRef jarg1, HandleRef jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_wsp_decorate")]
  public static extern IntPtr zxid_wsp_decorate(HandleRef jarg1, HandleRef jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_wsp_decoratef")]
  public static extern IntPtr zxid_wsp_decoratef(HandleRef jarg1, HandleRef jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_wsf_decor")]
  public static extern IntPtr zxid_wsf_decor(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_map_sec_mech")]
  public static extern int zxid_map_sec_mech(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_wsc_call")]
  public static extern IntPtr zxid_wsc_call(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_call")]
  public static extern IntPtr zxid_call(HandleRef jarg1, HandleRef jarg2, string jarg3, string jarg4, string jarg5, string jarg6, string jarg7);

  [DllImport("zxid", EntryPoint="CSharp_zxid_callf")]
  public static extern IntPtr zxid_callf(HandleRef jarg1, HandleRef jarg2, string jarg3, string jarg4, string jarg5, string jarg6, string jarg7);

  [DllImport("zxid", EntryPoint="CSharp_zxid_nice_sha1")]
  public static extern int zxid_nice_sha1(HandleRef jarg1, string jarg2, int jarg3, HandleRef jarg4, HandleRef jarg5, int jarg6);

  [DllImport("zxid", EntryPoint="CSharp_zxid_fold_svc")]
  public static extern void zxid_fold_svc(string jarg1, int jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_epr_path")]
  public static extern int zxid_epr_path(HandleRef jarg1, string jarg2, string jarg3, string jarg4, int jarg5, HandleRef jarg6, HandleRef jarg7);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_epr")]
  public static extern IntPtr zxid_get_epr(HandleRef jarg1, HandleRef jarg2, string jarg3, string jarg4, string jarg5, string jarg6, int jarg7);

  [DllImport("zxid", EntryPoint="CSharp_zxid_find_epr")]
  public static extern IntPtr zxid_find_epr(HandleRef jarg1, HandleRef jarg2, string jarg3, string jarg4, string jarg5, string jarg6, int jarg7);

  [DllImport("zxid", EntryPoint="CSharp_zxid_cache_epr")]
  public static extern int zxid_cache_epr(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zxid_snarf_eprs_from_ses")]
  public static extern void zxid_snarf_eprs_from_ses(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_epr_address")]
  public static extern IntPtr zxid_get_epr_address(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_get_epr_entid")]
  public static extern IntPtr zxid_get_epr_entid(HandleRef jarg1, HandleRef jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_di_query")]
  public static extern IntPtr zxid_di_query(HandleRef jarg1, HandleRef jarg2, HandleRef jarg3);

  [DllImport("zxid", EntryPoint="CSharp_ZXID_DAP_SCOPE_BASE_get")]
  public static extern int ZXID_DAP_SCOPE_BASE_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_DAP_SCOPE_SINGLE_get")]
  public static extern int ZXID_DAP_SCOPE_SINGLE_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_DAP_SCOPE_SUBTREE_get")]
  public static extern int ZXID_DAP_SCOPE_SUBTREE_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_CDC_CHOICE_ALWAYS_FIRST_get")]
  public static extern int ZXID_CDC_CHOICE_ALWAYS_FIRST_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_CDC_CHOICE_ALWAYS_LAST_get")]
  public static extern int ZXID_CDC_CHOICE_ALWAYS_LAST_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_CDC_CHOICE_ALWAYS_ONLY_get")]
  public static extern int ZXID_CDC_CHOICE_ALWAYS_ONLY_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_CDC_CHOICE_UI_PREF_get")]
  public static extern int ZXID_CDC_CHOICE_UI_PREF_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_CDC_CHOICE_UI_NOPREF_get")]
  public static extern int ZXID_CDC_CHOICE_UI_NOPREF_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_CDC_CHOICE_UI_ONLY_CDC_get")]
  public static extern int ZXID_CDC_CHOICE_UI_ONLY_CDC_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SAML2_ART_get")]
  public static extern int ZXID_SAML2_ART_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SAML2_POST_get")]
  public static extern int ZXID_SAML2_POST_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SAML2_PAOS_get")]
  public static extern int ZXID_SAML2_PAOS_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SAML2_SOAP_get")]
  public static extern int ZXID_SAML2_SOAP_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SAML2_POST_SIMPLE_SIGN_get")]
  public static extern int ZXID_SAML2_POST_SIMPLE_SIGN_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SAML2_REDIR_get")]
  public static extern int ZXID_SAML2_REDIR_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SAML2_URI_get")]
  public static extern int ZXID_SAML2_URI_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SLO_SVC_get")]
  public static extern int ZXID_SLO_SVC_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_MNI_SVC_get")]
  public static extern int ZXID_MNI_SVC_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_ACS_SVC_get")]
  public static extern int ZXID_ACS_SVC_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SEC_MECH_NULL_get")]
  public static extern int ZXID_SEC_MECH_NULL_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SEC_MECH_BEARER_get")]
  public static extern int ZXID_SEC_MECH_BEARER_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SEC_MECH_SAML_get")]
  public static extern int ZXID_SEC_MECH_SAML_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SEC_MECH_X509_get")]
  public static extern int ZXID_SEC_MECH_X509_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SEC_MECH_PEERS_get")]
  public static extern int ZXID_SEC_MECH_PEERS_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_FAIL_get")]
  public static extern int ZXID_FAIL_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_OK_get")]
  public static extern int ZXID_OK_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_REDIR_OK_get")]
  public static extern int ZXID_REDIR_OK_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_SSO_OK_get")]
  public static extern int ZXID_SSO_OK_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_IDP_REQ_get")]
  public static extern int ZXID_IDP_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_TRUE_get")]
  public static extern string ZXID_TRUE_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_FALSE_get")]
  public static extern string ZXID_FALSE_get();

  [DllImport("zxid", EntryPoint="CSharp_CRLF_get")]
  public static extern string CRLF_get();

  [DllImport("zxid", EntryPoint="CSharp_CRLF2_get")]
  public static extern string CRLF2_get();

  [DllImport("zxid", EntryPoint="CSharp_std_basis_64_set")]
  public static extern void std_basis_64_set(string jarg1);

  [DllImport("zxid", EntryPoint="CSharp_std_basis_64_get")]
  public static extern string std_basis_64_get();

  [DllImport("zxid", EntryPoint="CSharp_safe_basis_64_set")]
  public static extern void safe_basis_64_set(string jarg1);

  [DllImport("zxid", EntryPoint="CSharp_safe_basis_64_get")]
  public static extern string safe_basis_64_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_std_index_64_set")]
  public static extern void zx_std_index_64_set(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_std_index_64_get")]
  public static extern IntPtr zx_std_index_64_get();

  [DllImport("zxid", EntryPoint="CSharp_base64_fancy_raw")]
  public static extern string base64_fancy_raw(string jarg1, int jarg2, string jarg3, string jarg4, int jarg5, int jarg6, string jarg7, char jarg8);

  [DllImport("zxid", EntryPoint="CSharp_unbase64_raw")]
  public static extern string unbase64_raw(string jarg1, string jarg2, string jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_sha1_safe_base64")]
  public static extern string sha1_safe_base64(string jarg1, int jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_zlib_raw_deflate")]
  public static extern string zx_zlib_raw_deflate(HandleRef jarg1, int jarg2, string jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_zlib_raw_inflate")]
  public static extern string zx_zlib_raw_inflate(HandleRef jarg1, int jarg2, string jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zx_url_encode_len")]
  public static extern int zx_url_encode_len(int jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zx_url_encode_raw")]
  public static extern string zx_url_encode_raw(int jarg1, string jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_zx_url_encode")]
  public static extern string zx_url_encode(HandleRef jarg1, int jarg2, string jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_hex_trans_set")]
  public static extern void hex_trans_set(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_hex_trans_get")]
  public static extern IntPtr hex_trans_get();

  [DllImport("zxid", EntryPoint="CSharp_ykmodhex_trans_set")]
  public static extern void ykmodhex_trans_set(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_ykmodhex_trans_get")]
  public static extern IntPtr ykmodhex_trans_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_hexdec")]
  public static extern string zx_hexdec(string jarg1, string jarg2, int jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_read_all")]
  public static extern int read_all(int jarg1, string jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_name_from_path")]
  public static extern int name_from_path(string jarg1, int jarg2, string jarg3);

  [DllImport("zxid", EntryPoint="CSharp_open_fd_from_path")]
  public static extern IntPtr open_fd_from_path(int jarg1, int jarg2, string jarg3, string jarg4);

  [DllImport("zxid", EntryPoint="CSharp_read_all_fd")]
  public static extern int read_all_fd(HandleRef jarg1, string jarg2, int jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_write_all_fd")]
  public static extern int write_all_fd(HandleRef jarg1, string jarg2, int jarg3);

  [DllImport("zxid", EntryPoint="CSharp_write_all_path_fmt")]
  public static extern int write_all_path_fmt(string jarg1, int jarg2, string jarg3, string jarg4, string jarg5, string jarg6, string jarg7);

  [DllImport("zxid", EntryPoint="CSharp_close_file")]
  public static extern int close_file(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_curl_ctx_p_set")]
  public static extern void zxid_curl_ctx_p_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_curl_ctx_p_get")]
  public static extern string zxid_curl_ctx_p_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_curl_ctx_lim_set")]
  public static extern void zxid_curl_ctx_lim_set(HandleRef jarg1, string jarg2);

  [DllImport("zxid", EntryPoint="CSharp_zxid_curl_ctx_lim_get")]
  public static extern string zxid_curl_ctx_lim_get(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_new_zxid_curl_ctx")]
  public static extern IntPtr new_zxid_curl_ctx();

  [DllImport("zxid", EntryPoint="CSharp_delete_zxid_curl_ctx")]
  public static extern void delete_zxid_curl_ctx(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zxid_curl_write_data")]
  public static extern uint zxid_curl_write_data(HandleRef jarg1, uint jarg2, uint jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_zxid_curl_read_data")]
  public static extern uint zxid_curl_read_data(HandleRef jarg1, uint jarg2, uint jarg3, HandleRef jarg4);

  [DllImport("zxid", EntryPoint="CSharp_SAML2_PROTO_get")]
  public static extern string SAML2_PROTO_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_VERSION_get")]
  public static extern string SAML2_VERSION_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_SUCCESS_get")]
  public static extern string SAML2_SC_SUCCESS_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_REQUESTER_get")]
  public static extern string SAML2_SC_REQUESTER_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_RESPONDER_get")]
  public static extern string SAML2_SC_RESPONDER_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_VERSION_get")]
  public static extern string SAML2_SC_VERSION_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_AUTHNFAIL_get")]
  public static extern string SAML2_SC_AUTHNFAIL_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_INVATTRNV_get")]
  public static extern string SAML2_SC_INVATTRNV_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_INVNIDPOL_get")]
  public static extern string SAML2_SC_INVNIDPOL_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_NOAUTNCTX_get")]
  public static extern string SAML2_SC_NOAUTNCTX_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_NOAVALIDP_get")]
  public static extern string SAML2_SC_NOAVALIDP_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_NOPASSIVE_get")]
  public static extern string SAML2_SC_NOPASSIVE_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_NOSUPPIDP_get")]
  public static extern string SAML2_SC_NOSUPPIDP_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_PARLOGOUT_get")]
  public static extern string SAML2_SC_PARLOGOUT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_PROXYCEXC_get")]
  public static extern string SAML2_SC_PROXYCEXC_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_REQDENIED_get")]
  public static extern string SAML2_SC_REQDENIED_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_REQUNSUPP_get")]
  public static extern string SAML2_SC_REQUNSUPP_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_REQVERDEP_get")]
  public static extern string SAML2_SC_REQVERDEP_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_REQVERHIG_get")]
  public static extern string SAML2_SC_REQVERHIG_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_REQVERLOW_get")]
  public static extern string SAML2_SC_REQVERLOW_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_RESONRECG_get")]
  public static extern string SAML2_SC_RESONRECG_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_TOOMNYRES_get")]
  public static extern string SAML2_SC_TOOMNYRES_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_UNKATTPRO_get")]
  public static extern string SAML2_SC_UNKATTPRO_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_UNKPRNCPL_get")]
  public static extern string SAML2_SC_UNKPRNCPL_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SC_UNSUPPBIN_get")]
  public static extern string SAML2_SC_UNSUPPBIN_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML_AUTHCTX_PASSWORDPROTECTED_get")]
  public static extern string SAML_AUTHCTX_PASSWORDPROTECTED_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML_AUTHCTX_PASSWORD_get")]
  public static extern string SAML_AUTHCTX_PASSWORD_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML_AUTHCTX_SSL_TLS_CERT_get")]
  public static extern string SAML_AUTHCTX_SSL_TLS_CERT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML_AUTHCTX_PREVSESS_get")]
  public static extern string SAML_AUTHCTX_PREVSESS_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML_AUTHCTX_UNSPCFD_get")]
  public static extern string SAML_AUTHCTX_UNSPCFD_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML_AUTHCTX_INPROT_get")]
  public static extern string SAML_AUTHCTX_INPROT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_UNSPECIFIED_NID_FMT_get")]
  public static extern string SAML2_UNSPECIFIED_NID_FMT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_EMAILADDR_NID_FMT_get")]
  public static extern string SAML2_EMAILADDR_NID_FMT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_X509_NID_FMT_get")]
  public static extern string SAML2_X509_NID_FMT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_WINDOMAINQN_NID_FMT_get")]
  public static extern string SAML2_WINDOMAINQN_NID_FMT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_KERBEROS_NID_FMT_get")]
  public static extern string SAML2_KERBEROS_NID_FMT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_ENTITY_NID_FMT_get")]
  public static extern string SAML2_ENTITY_NID_FMT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_PERSISTENT_NID_FMT_get")]
  public static extern string SAML2_PERSISTENT_NID_FMT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_TRANSIENT_NID_FMT_get")]
  public static extern string SAML2_TRANSIENT_NID_FMT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SSO_BRWS_get")]
  public static extern string SAML2_SSO_BRWS_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SSO_ECP_get")]
  public static extern string SAML2_SSO_ECP_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SLO_get")]
  public static extern string SAML2_SLO_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_NIREG_get")]
  public static extern string SAML2_NIREG_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_NIMAP_get")]
  public static extern string SAML2_NIMAP_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_ARTIFACT_get")]
  public static extern string SAML2_ARTIFACT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_QUERY_get")]
  public static extern string SAML2_QUERY_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_PAOS_get")]
  public static extern string SAML2_PAOS_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SOAP_get")]
  public static extern string SAML2_SOAP_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_REDIR_get")]
  public static extern string SAML2_REDIR_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_ART_get")]
  public static extern string SAML2_ART_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_POST_get")]
  public static extern string SAML2_POST_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_POST_SIMPLE_SIGN_get")]
  public static extern string SAML2_POST_SIMPLE_SIGN_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_URI_get")]
  public static extern string SAML2_URI_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_AP_BASIC_get")]
  public static extern string SAML2_AP_BASIC_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_AP_X500_get")]
  public static extern string SAML2_AP_X500_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_AP_UUID_get")]
  public static extern string SAML2_AP_UUID_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_AP_DCE_get")]
  public static extern string SAML2_AP_DCE_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_AP_XACML_get")]
  public static extern string SAML2_AP_XACML_get();

  [DllImport("zxid", EntryPoint="CSharp_ATTRNAME_UNSPECIFIED_get")]
  public static extern string ATTRNAME_UNSPECIFIED_get();

  [DllImport("zxid", EntryPoint="CSharp_ATTRNAME_BASIC_get")]
  public static extern string ATTRNAME_BASIC_get();

  [DllImport("zxid", EntryPoint="CSharp_SOAP_ACTOR_NEXT_get")]
  public static extern string SOAP_ACTOR_NEXT_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_BEARER_get")]
  public static extern string SAML2_BEARER_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_SOAP_ACTION_get")]
  public static extern string SAML2_SOAP_ACTION_get();

  [DllImport("zxid", EntryPoint="CSharp_ACTION_RW_get")]
  public static extern string ACTION_RW_get();

  [DllImport("zxid", EntryPoint="CSharp_ACTION_RWN_get")]
  public static extern string ACTION_RWN_get();

  [DllImport("zxid", EntryPoint="CSharp_ACTION_GHPP_get")]
  public static extern string ACTION_GHPP_get();

  [DllImport("zxid", EntryPoint="CSharp_ACTION_UNIX_get")]
  public static extern string ACTION_UNIX_get();

  [DllImport("zxid", EntryPoint="CSharp_PAOS_CONTENT_get")]
  public static extern string PAOS_CONTENT_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_SA_get")]
  public static extern string XMLNS_SA_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_IMS_get")]
  public static extern string XMLNS_IMS_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_LIB_get")]
  public static extern string XMLNS_LIB_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_SASL_REQ_get")]
  public static extern string ACT_SASL_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_SASL_RES_get")]
  public static extern string ACT_SASL_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_PWTRUNCATE_get")]
  public static extern string PWTRUNCATE_get();

  [DllImport("zxid", EntryPoint="CSharp_PWLOWERCASE_get")]
  public static extern string PWLOWERCASE_get();

  [DllImport("zxid", EntryPoint="CSharp_PWUPPERCASE_get")]
  public static extern string PWUPPERCASE_get();

  [DllImport("zxid", EntryPoint="CSharp_PWSELECT_get")]
  public static extern string PWSELECT_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_SUBS_get")]
  public static extern string XMLNS_SUBS_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_SUBSREF_get")]
  public static extern string XMLNS_SUBSREF_get();

  [DllImport("zxid", EntryPoint="CSharp_SUBS_OPT_NOSUBSCIB_get")]
  public static extern string SUBS_OPT_NOSUBSCIB_get();

  [DllImport("zxid", EntryPoint="CSharp_SUBS_OPT_NOQUESUBS_get")]
  public static extern string SUBS_OPT_NOQUESUBS_get();

  [DllImport("zxid", EntryPoint="CSharp_SUBS_END_EXPIRED_get")]
  public static extern string SUBS_END_EXPIRED_get();

  [DllImport("zxid", EntryPoint="CSharp_SUBS_END_DELETED_get")]
  public static extern string SUBS_END_DELETED_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_DI_RO_get")]
  public static extern string WSF11_DI_RO_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF20_DI_RO_get")]
  public static extern string WSF20_DI_RO_get();

  [DllImport("zxid", EntryPoint="CSharp_IMPLIED_RSC_get")]
  public static extern string IMPLIED_RSC_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_DISCO_1_1_get")]
  public static extern string XMLNS_DISCO_1_1_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_DISCO_EXT_get")]
  public static extern string XMLNS_DISCO_EXT_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_DISCO_2_0_get")]
  public static extern string XMLNS_DISCO_2_0_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_SBF_get")]
  public static extern string XMLNS_SBF_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_QUE_get")]
  public static extern string ACT_QUE_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_QUE_RES_get")]
  public static extern string ACT_QUE_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_ASSO_QUE_get")]
  public static extern string ACT_ASSO_QUE_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_ASSO_QUE_RES_get")]
  public static extern string ACT_ASSO_QUE_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_ASSO_ADD_get")]
  public static extern string ACT_ASSO_ADD_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_ASSO_ADD_RES_get")]
  public static extern string ACT_ASSO_ADD_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_ASSO_DEL_get")]
  public static extern string ACT_ASSO_DEL_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_ASSO_DEL_RES_get")]
  public static extern string ACT_ASSO_DEL_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_SVCMD_QUE_get")]
  public static extern string ACT_SVCMD_QUE_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_SVCMD_QUE_RES_get")]
  public static extern string ACT_SVCMD_QUE_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_SVCMD_REG_get")]
  public static extern string ACT_SVCMD_REG_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_SVCMD_REG_RES_get")]
  public static extern string ACT_SVCMD_REG_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_SVCMD_REP_get")]
  public static extern string ACT_SVCMD_REP_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_SVCMD_REP_RES_get")]
  public static extern string ACT_SVCMD_REP_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_SVCMD_DEL_get")]
  public static extern string ACT_SVCMD_DEL_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_SVCMD_DEL_RES_get")]
  public static extern string ACT_SVCMD_DEL_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_GL_get")]
  public static extern string XMLNS_GL_get();

  [DllImport("zxid", EntryPoint="CSharp_GL_OPT_SHAPE_get")]
  public static extern string GL_OPT_SHAPE_get();

  [DllImport("zxid", EntryPoint="CSharp_GL_OPT_SPEED_get")]
  public static extern string GL_OPT_SPEED_get();

  [DllImport("zxid", EntryPoint="CSharp_GL_OPT_DIRECTION_get")]
  public static extern string GL_OPT_DIRECTION_get();

  [DllImport("zxid", EntryPoint="CSharp_GL_OPT_HEADING_get")]
  public static extern string GL_OPT_HEADING_get();

  [DllImport("zxid", EntryPoint="CSharp_GL_OPT_ALT_get")]
  public static extern string GL_OPT_ALT_get();

  [DllImport("zxid", EntryPoint="CSharp_GL_OPT_CIVIL_DATA_get")]
  public static extern string GL_OPT_CIVIL_DATA_get();

  [DllImport("zxid", EntryPoint="CSharp_GL_OPT_AC_get")]
  public static extern string GL_OPT_AC_get();

  [DllImport("zxid", EntryPoint="CSharp_GL_OPT_AC_ONLY_get")]
  public static extern string GL_OPT_AC_ONLY_get();

  [DllImport("zxid", EntryPoint="CSharp_GL_OPT_ACC_HIGH_get")]
  public static extern string GL_OPT_ACC_HIGH_get();

  [DllImport("zxid", EntryPoint="CSharp_GL_OPT_ACC_MEDIUM_get")]
  public static extern string GL_OPT_ACC_MEDIUM_get();

  [DllImport("zxid", EntryPoint="CSharp_GL_OPT_ACC_LOW_get")]
  public static extern string GL_OPT_ACC_LOW_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_IS11_get")]
  public static extern string XMLNS_IS11_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_IS20_get")]
  public static extern string XMLNS_IS20_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_IREQ_get")]
  public static extern string ACT_IREQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_IRES_get")]
  public static extern string ACT_IRES_get();

  [DllImport("zxid", EntryPoint="CSharp_OPT_PP_get")]
  public static extern string OPT_PP_get();

  [DllImport("zxid", EntryPoint="CSharp_OPT_PP_INAME_get")]
  public static extern string OPT_PP_INAME_get();

  [DllImport("zxid", EntryPoint="CSharp_OPT_PP_CN_get")]
  public static extern string OPT_PP_CN_get();

  [DllImport("zxid", EntryPoint="CSharp_OPT_PP_LEG_get")]
  public static extern string OPT_PP_LEG_get();

  [DllImport("zxid", EntryPoint="CSharp_OPT_PP_ADD_get")]
  public static extern string OPT_PP_ADD_get();

  [DllImport("zxid", EntryPoint="CSharp_OPTC_PP_get")]
  public static extern string OPTC_PP_get();

  [DllImport("zxid", EntryPoint="CSharp_OPTC_PP_INAME_get")]
  public static extern string OPTC_PP_INAME_get();

  [DllImport("zxid", EntryPoint="CSharp_OPTC_PP_CN_get")]
  public static extern string OPTC_PP_CN_get();

  [DllImport("zxid", EntryPoint="CSharp_OPTC_PP_LEG_get")]
  public static extern string OPTC_PP_LEG_get();

  [DllImport("zxid", EntryPoint="CSharp_OPTC_PP_ADD_get")]
  public static extern string OPTC_PP_ADD_get();

  [DllImport("zxid", EntryPoint="CSharp_OPT_MULT_QI_get")]
  public static extern string OPT_MULT_QI_get();

  [DllImport("zxid", EntryPoint="CSharp_OPT_MULT_MI_get")]
  public static extern string OPT_MULT_MI_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_PP_get")]
  public static extern string XMLNS_PP_get();

  [DllImport("zxid", EntryPoint="CSharp_PS_COL_get")]
  public static extern string PS_COL_get();

  [DllImport("zxid", EntryPoint="CSharp_PS_ENT_get")]
  public static extern string PS_ENT_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_PS_get")]
  public static extern string XMLNS_PS_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_ADDENT_REQ_get")]
  public static extern string ACT_PS_ADDENT_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_ADDENT_RES_get")]
  public static extern string ACT_PS_ADDENT_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_ADDKENT_REQ_get")]
  public static extern string ACT_PS_ADDKENT_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_ADDKENT_RES_get")]
  public static extern string ACT_PS_ADDKENT_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_REMENT_REQ_get")]
  public static extern string ACT_PS_REMENT_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_REMENT_RES_get")]
  public static extern string ACT_PS_REMENT_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_ADDCOL_REQ_get")]
  public static extern string ACT_PS_ADDCOL_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_ADDCOL_RES_get")]
  public static extern string ACT_PS_ADDCOL_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_REMCOL_REQ_get")]
  public static extern string ACT_PS_REMCOL_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_REMCOL_RES_get")]
  public static extern string ACT_PS_REMCOL_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_ADDTOCOL_REQ_get")]
  public static extern string ACT_PS_ADDTOCOL_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_ADDTOCOL_RES_get")]
  public static extern string ACT_PS_ADDTOCOL_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_REMFROMCOL_REQ_get")]
  public static extern string ACT_PS_REMFROMCOL_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_REMFROMCOL_RES_get")]
  public static extern string ACT_PS_REMFROMCOL_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_LISTMEM_REQ_get")]
  public static extern string ACT_PS_LISTMEM_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_LISTMEM_RES_get")]
  public static extern string ACT_PS_LISTMEM_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_GETOBJ_REQ_get")]
  public static extern string ACT_PS_GETOBJ_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_GETOBJ_RES_get")]
  public static extern string ACT_PS_GETOBJ_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_SETOBJ_REQ_get")]
  public static extern string ACT_PS_SETOBJ_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_SETOBJ_RES_get")]
  public static extern string ACT_PS_SETOBJ_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_QUEOBJ_REQ_get")]
  public static extern string ACT_PS_QUEOBJ_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_QUEOBJ_RES_get")]
  public static extern string ACT_PS_QUEOBJ_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_TESTMEM_REQ_get")]
  public static extern string ACT_PS_TESTMEM_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_TESTMEM_RES_get")]
  public static extern string ACT_PS_TESTMEM_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_RSLVID_REQ_get")]
  public static extern string ACT_PS_RSLVID_REQ_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_RSLVID_RES_get")]
  public static extern string ACT_PS_RSLVID_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_NOTIFY_get")]
  public static extern string ACT_PS_NOTIFY_get();

  [DllImport("zxid", EntryPoint="CSharp_ACT_PS_NOTIFY_RES_get")]
  public static extern string ACT_PS_NOTIFY_RES_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_SEC_get")]
  public static extern string XMLNS_SEC_get();

  [DllImport("zxid", EntryPoint="CSharp_TOKNUSG_SEC_get")]
  public static extern string TOKNUSG_SEC_get();

  [DllImport("zxid", EntryPoint="CSharp_TOKNUSG_TID_get")]
  public static extern string TOKNUSG_TID_get();

  [DllImport("zxid", EntryPoint="CSharp_TOKNUSG_IID_get")]
  public static extern string TOKNUSG_IID_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF10_SEC_MECH_NULL_BEARER_get")]
  public static extern string WSF10_SEC_MECH_NULL_BEARER_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF10_SEC_MECH_TLS_BEARER_get")]
  public static extern string WSF10_SEC_MECH_TLS_BEARER_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_SEC_MECH_NULL_NULL_get")]
  public static extern string WSF11_SEC_MECH_NULL_NULL_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_SEC_MECH_TLS_NULL_get")]
  public static extern string WSF11_SEC_MECH_TLS_NULL_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_SEC_MECH_CLTLS_NULL_get")]
  public static extern string WSF11_SEC_MECH_CLTLS_NULL_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_SEC_MECH_NULL_BEARER_get")]
  public static extern string WSF11_SEC_MECH_NULL_BEARER_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_SEC_MECH_TLS_BEARER_get")]
  public static extern string WSF11_SEC_MECH_TLS_BEARER_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_SEC_MECH_CLTLS_BEARER_get")]
  public static extern string WSF11_SEC_MECH_CLTLS_BEARER_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_SEC_MECH_NULL_X509_get")]
  public static extern string WSF11_SEC_MECH_NULL_X509_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_SEC_MECH_TLS_X509_get")]
  public static extern string WSF11_SEC_MECH_TLS_X509_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_SEC_MECH_CLTLS_X509_get")]
  public static extern string WSF11_SEC_MECH_CLTLS_X509_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_SEC_MECH_NULL_SAML_get")]
  public static extern string WSF11_SEC_MECH_NULL_SAML_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_SEC_MECH_TLS_SAML_get")]
  public static extern string WSF11_SEC_MECH_TLS_SAML_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF11_SEC_MECH_CLTLS_SAML_get")]
  public static extern string WSF11_SEC_MECH_CLTLS_SAML_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF20_SEC_MECH_NULL_NULL_get")]
  public static extern string WSF20_SEC_MECH_NULL_NULL_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF20_SEC_MECH_TLS_NULL_get")]
  public static extern string WSF20_SEC_MECH_TLS_NULL_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF20_SEC_MECH_NULL_BEARER_get")]
  public static extern string WSF20_SEC_MECH_NULL_BEARER_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF20_SEC_MECH_TLS_BEARER_get")]
  public static extern string WSF20_SEC_MECH_TLS_BEARER_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF20_SEC_MECH_NULL_SAML2_get")]
  public static extern string WSF20_SEC_MECH_NULL_SAML2_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF20_SEC_MECH_TLS_SAML2_get")]
  public static extern string WSF20_SEC_MECH_TLS_SAML2_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF20_SEC_MECH_CLTLS_SAML2_get")]
  public static extern string WSF20_SEC_MECH_CLTLS_SAML2_get();

  [DllImport("zxid", EntryPoint="CSharp_WSF20_SEC_MECH_CLTLS_PEERS2_get")]
  public static extern string WSF20_SEC_MECH_CLTLS_PEERS2_get();

  [DllImport("zxid", EntryPoint="CSharp_SAML2_TOK_PROFILE_get")]
  public static extern string SAML2_TOK_PROFILE_get();

  [DllImport("zxid", EntryPoint="CSharp_SAMLID_TOK_PROFILE_get")]
  public static extern string SAMLID_TOK_PROFILE_get();

  [DllImport("zxid", EntryPoint="CSharp_WSS_X509_TOKEN_PROFILE_get")]
  public static extern string WSS_X509_TOKEN_PROFILE_get();

  [DllImport("zxid", EntryPoint="CSharp_SB_EPUPD_COMP_get")]
  public static extern string SB_EPUPD_COMP_get();

  [DllImport("zxid", EntryPoint="CSharp_SB_EPUPD_PART_get")]
  public static extern string SB_EPUPD_PART_get();

  [DllImport("zxid", EntryPoint="CSharp_SB_EPUPD_NOCH_get")]
  public static extern string SB_EPUPD_NOCH_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_CSM_get")]
  public static extern string XMLNS_CSM_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_LU_get")]
  public static extern string XMLNS_LU_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_HLO_get")]
  public static extern string XMLNS_HLO_get();

  [DllImport("zxid", EntryPoint="CSharp_DST_ACC_CHALLENGE_get")]
  public static extern string DST_ACC_CHALLENGE_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_CXP_get")]
  public static extern string XMLNS_CXP_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_LIB_MD_get")]
  public static extern string XMLNS_LIB_MD_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_AC_get")]
  public static extern string XMLNS_AC_get();

  [DllImport("zxid", EntryPoint="CSharp_LIBERTY_NAMEID_FMT_FED_get")]
  public static extern string LIBERTY_NAMEID_FMT_FED_get();

  [DllImport("zxid", EntryPoint="CSharp_LIBERTY_NAMEID_FMT_ONE_get")]
  public static extern string LIBERTY_NAMEID_FMT_ONE_get();

  [DllImport("zxid", EntryPoint="CSharp_LIBERTY_NAMEID_FMT_ENC_get")]
  public static extern string LIBERTY_NAMEID_FMT_ENC_get();

  [DllImport("zxid", EntryPoint="CSharp_LIBERTY_NAMEID_FMT_ENT_get")]
  public static extern string LIBERTY_NAMEID_FMT_ENT_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_PAOS_get")]
  public static extern string XMLNS_PAOS_get();

  [DllImport("zxid", EntryPoint="CSharp_PAOS_HDR_get")]
  public static extern string PAOS_HDR_get();

  [DllImport("zxid", EntryPoint="CSharp_LIBERTY_ENA_HDR_get")]
  public static extern string LIBERTY_ENA_HDR_get();

  [DllImport("zxid", EntryPoint="CSharp_LIBERTY_CONSENT_OBTAINED_get")]
  public static extern string LIBERTY_CONSENT_OBTAINED_get();

  [DllImport("zxid", EntryPoint="CSharp_XMLNS_DAP_get")]
  public static extern string XMLNS_DAP_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_VERSION_get")]
  public static extern int ZXID_VERSION_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_REL_get")]
  public static extern string ZXID_REL_get();

  [DllImport("zxid", EntryPoint="CSharp_ZXID_COMPILE_DATE_get")]
  public static extern string ZXID_COMPILE_DATE_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_tab_set")]
  public static extern void zx_ns_tab_set(HandleRef jarg1);

  [DllImport("zxid", EntryPoint="CSharp_zx_ns_tab_get")]
  public static extern IntPtr zx_ns_tab_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_ds_get")]
  public static extern int zx_xmlns_ix_ds_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ds_get")]
  public static extern string zx_xmlns_ds_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_xenc_get")]
  public static extern int zx_xmlns_ix_xenc_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_xenc_get")]
  public static extern string zx_xmlns_xenc_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_exca_get")]
  public static extern int zx_xmlns_ix_exca_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_exca_get")]
  public static extern string zx_xmlns_exca_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_sa_get")]
  public static extern int zx_xmlns_ix_sa_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_sa_get")]
  public static extern string zx_xmlns_sa_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_sp_get")]
  public static extern int zx_xmlns_ix_sp_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_sp_get")]
  public static extern string zx_xmlns_sp_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_ecp_get")]
  public static extern int zx_xmlns_ix_ecp_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ecp_get")]
  public static extern string zx_xmlns_ecp_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_paos_get")]
  public static extern int zx_xmlns_ix_paos_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_paos_get")]
  public static extern string zx_xmlns_paos_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_e_get")]
  public static extern int zx_xmlns_ix_e_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_e_get")]
  public static extern string zx_xmlns_e_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_md_get")]
  public static extern int zx_xmlns_ix_md_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_md_get")]
  public static extern string zx_xmlns_md_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_shibmd_get")]
  public static extern int zx_xmlns_ix_shibmd_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_shibmd_get")]
  public static extern string zx_xmlns_shibmd_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_sp11_get")]
  public static extern int zx_xmlns_ix_sp11_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_sp11_get")]
  public static extern string zx_xmlns_sp11_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_sa11_get")]
  public static extern int zx_xmlns_ix_sa11_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_sa11_get")]
  public static extern string zx_xmlns_sa11_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_ff12_get")]
  public static extern int zx_xmlns_ix_ff12_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ff12_get")]
  public static extern string zx_xmlns_ff12_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_ac_get")]
  public static extern int zx_xmlns_ix_ac_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ac_get")]
  public static extern string zx_xmlns_ac_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_m20_get")]
  public static extern int zx_xmlns_ix_m20_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_m20_get")]
  public static extern string zx_xmlns_m20_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_a_get")]
  public static extern int zx_xmlns_ix_a_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_a_get")]
  public static extern string zx_xmlns_a_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_wsse_get")]
  public static extern int zx_xmlns_ix_wsse_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_wsse_get")]
  public static extern string zx_xmlns_wsse_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_wsu_get")]
  public static extern int zx_xmlns_ix_wsu_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_wsu_get")]
  public static extern string zx_xmlns_wsu_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_sbf_get")]
  public static extern int zx_xmlns_ix_sbf_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_sbf_get")]
  public static extern string zx_xmlns_sbf_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_b_get")]
  public static extern int zx_xmlns_ix_b_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_b_get")]
  public static extern string zx_xmlns_b_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_sec_get")]
  public static extern int zx_xmlns_ix_sec_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_sec_get")]
  public static extern string zx_xmlns_sec_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_di_get")]
  public static extern int zx_xmlns_ix_di_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_di_get")]
  public static extern string zx_xmlns_di_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_is_get")]
  public static extern int zx_xmlns_ix_is_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_is_get")]
  public static extern string zx_xmlns_is_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_lu_get")]
  public static extern int zx_xmlns_ix_lu_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_lu_get")]
  public static extern string zx_xmlns_lu_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_dap_get")]
  public static extern int zx_xmlns_ix_dap_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_dap_get")]
  public static extern string zx_xmlns_dap_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_subs_get")]
  public static extern int zx_xmlns_ix_subs_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_subs_get")]
  public static extern string zx_xmlns_subs_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_dst_get")]
  public static extern int zx_xmlns_ix_dst_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_dst_get")]
  public static extern string zx_xmlns_dst_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_im_get")]
  public static extern int zx_xmlns_ix_im_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_im_get")]
  public static extern string zx_xmlns_im_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_ps_get")]
  public static extern int zx_xmlns_ix_ps_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ps_get")]
  public static extern string zx_xmlns_ps_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_as_get")]
  public static extern int zx_xmlns_ix_as_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_as_get")]
  public static extern string zx_xmlns_as_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_xml_get")]
  public static extern int zx_xmlns_ix_xml_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_xml_get")]
  public static extern string zx_xmlns_xml_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_xsi_get")]
  public static extern int zx_xmlns_ix_xsi_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_xsi_get")]
  public static extern string zx_xmlns_xsi_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_xs_get")]
  public static extern int zx_xmlns_ix_xs_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_xs_get")]
  public static extern string zx_xmlns_xs_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_mm7_get")]
  public static extern int zx_xmlns_ix_mm7_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_mm7_get")]
  public static extern string zx_xmlns_mm7_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_cb_get")]
  public static extern int zx_xmlns_ix_cb_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_cb_get")]
  public static extern string zx_xmlns_cb_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_cdm_get")]
  public static extern int zx_xmlns_ix_cdm_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_cdm_get")]
  public static extern string zx_xmlns_cdm_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_gl_get")]
  public static extern int zx_xmlns_ix_gl_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_gl_get")]
  public static extern string zx_xmlns_gl_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_dp_get")]
  public static extern int zx_xmlns_ix_dp_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_dp_get")]
  public static extern string zx_xmlns_dp_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_idp_get")]
  public static extern int zx_xmlns_ix_idp_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_idp_get")]
  public static extern string zx_xmlns_idp_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_pmm_get")]
  public static extern int zx_xmlns_ix_pmm_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_pmm_get")]
  public static extern string zx_xmlns_pmm_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_prov_get")]
  public static extern int zx_xmlns_ix_prov_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_prov_get")]
  public static extern string zx_xmlns_prov_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_shps_get")]
  public static extern int zx_xmlns_ix_shps_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_shps_get")]
  public static extern string zx_xmlns_shps_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_hrxml_get")]
  public static extern int zx_xmlns_ix_hrxml_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_hrxml_get")]
  public static extern string zx_xmlns_hrxml_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_idhrxml_get")]
  public static extern int zx_xmlns_ix_idhrxml_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_idhrxml_get")]
  public static extern string zx_xmlns_idhrxml_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_demomed_get")]
  public static extern int zx_xmlns_ix_demomed_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_demomed_get")]
  public static extern string zx_xmlns_demomed_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_b12_get")]
  public static extern int zx_xmlns_ix_b12_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_b12_get")]
  public static extern string zx_xmlns_b12_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_sec12_get")]
  public static extern int zx_xmlns_ix_sec12_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_sec12_get")]
  public static extern string zx_xmlns_sec12_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_di12_get")]
  public static extern int zx_xmlns_ix_di12_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_di12_get")]
  public static extern string zx_xmlns_di12_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_is12_get")]
  public static extern int zx_xmlns_ix_is12_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_is12_get")]
  public static extern string zx_xmlns_is12_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_xac_get")]
  public static extern int zx_xmlns_ix_xac_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_xac_get")]
  public static extern string zx_xmlns_xac_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_xa_get")]
  public static extern int zx_xmlns_ix_xa_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_xa_get")]
  public static extern string zx_xmlns_xa_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_xasa_get")]
  public static extern int zx_xmlns_ix_xasa_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_xasa_get")]
  public static extern string zx_xmlns_xasa_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_xasp_get")]
  public static extern int zx_xmlns_ix_xasp_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_xasp_get")]
  public static extern string zx_xmlns_xasp_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_xaspcd1_get")]
  public static extern int zx_xmlns_ix_xaspcd1_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_xaspcd1_get")]
  public static extern string zx_xmlns_xaspcd1_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_xasacd1_get")]
  public static extern int zx_xmlns_ix_xasacd1_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_xasacd1_get")]
  public static extern string zx_xmlns_xasacd1_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_wst_get")]
  public static extern int zx_xmlns_ix_wst_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_wst_get")]
  public static extern string zx_xmlns_wst_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_wsp_get")]
  public static extern int zx_xmlns_ix_wsp_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_wsp_get")]
  public static extern string zx_xmlns_wsp_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_wsc_get")]
  public static extern int zx_xmlns_ix_wsc_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_wsc_get")]
  public static extern string zx_xmlns_wsc_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_tas3_get")]
  public static extern int zx_xmlns_ix_tas3_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_tas3_get")]
  public static extern string zx_xmlns_tas3_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_ix_tas3sol_get")]
  public static extern int zx_xmlns_ix_tas3sol_get();

  [DllImport("zxid", EntryPoint="CSharp_zx_xmlns_tas3sol_get")]
  public static extern string zx_xmlns_tas3sol_get();
}
